<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';

$utility = new Utility();

try {
    $database = new DataBase();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, [
        'user_message' => "متأسفانه ارتباط با پایگاه داده برقرار نشد. لطفاً مجدداً تلاش کنید.",
        'developer_message' => "Database connection error: " . $e->getMessage()
    ]);
    die();
}

$resume = new Resume($conn);

// دریافت و اعتبارسنجی پارامترهای ورودی
$searchKeyword = isset($_GET['user_keyword']) ? sanitizeInput($_GET['user_keyword']) : null;
$province = isset($_GET['user_province']) ? sanitizeInput($_GET['user_province']) : null;
$city = isset($_GET['user_city']) ? sanitizeInput($_GET['user_city']) : null;
$tables = isset($_GET['tables']) && !empty($_GET['tables']) ? array_map('sanitizeInput', explode(",", $_GET['tables'])) : [];
$statuses = isset($_GET['status']) && !empty($_GET['status']) ? array_map('sanitizeInput', explode(",", $_GET['status'])) : [];
$page = isset($_GET['page']) ? intval($_GET['page']) : 1; // شماره صفحه
$limit = isset($_GET['limit']) ? intval($_GET['limit']) : 10; // تعداد آیتم‌ها در هر صفحه

// اعتبارسنجی صفحه و محدودیت
if ($page < 1) {
    $page = 1;
}
if ($limit < 1) {
    $limit = 10;
}

// ساخت شرط‌های فیلتر
$filterConditions = [];
$filters = [];

if (!empty($province)) {
    $filterConditions[] = "province = :province";
    $filters[':province'] = $province;
}

if (!empty($city)) {
    $filterConditions[] = "city = :city";
    $filters[':city'] = $city;
}

if (!empty($statuses)) {
    $statusPlaceholders = [];
    foreach ($statuses as $index => $status) {
        $placeholder = ":status" . $index;
        $statusPlaceholders[] = "status = $placeholder";
        $filters[$placeholder] = $status;
    }
    $filterConditions[] = "(" . implode(" OR ", $statusPlaceholders) . ")";
}

// تعریف جداول و فیلدهای مربوطه
$tableFields = [
    'person_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'skills'
    ],
    'student_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'student_field'
    ],
    'teacher_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'teacher_field'
    ],
    'transportation_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'car_category'
    ],
    'club_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'sport_fields'
    ],
    'company_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'company_category'
    ],
    'school_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'educational_fields'
    ],
    'store_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'store_category'
    ],
    'workshop_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'workshop_category'
    ]
];

// انتخاب جداول مورد نظر یا همه جداول
$selectedTables = !empty($tables) ? array_intersect($tables, array_keys($tableFields)) : array_keys($tableFields);

// جداولی که جستجو بر اساس اسم و فامیلی در آن‌ها انجام می‌شود
$nameSearchTables = ['person_resume', 'teacher_resume', 'transportation_resume'];

// جداولی که جستجو بر اساس name در آن‌ها انجام می‌شود
$nameOnlyTables = ['club_resume', 'company_resume', 'school_resume', 'store_resume', 'workshop_resume'];

// تقسیم کلمه کلیدی به اسم و فامیلی
$nameParts = [];
if ($searchKeyword) {
    $nameParts = explode(" ", $searchKeyword, 2); // تقسیم به دو بخش (اسم و فامیلی)
}

// ساخت کوئری نهایی با پشتیبانی از پینگینگ
$unionQueries = [];
foreach ($selectedTables as $table) {
    $fields = $tableFields[$table];
    $whereClause = "1=1";

    // افزودن شرط‌های فیلتر
    if (!empty($filterConditions)) {
        $whereClause .= " AND " . implode(" AND ", $filterConditions);
    }

    // افزودن شرط جستجو (اگر وجود دارد)
    if ($searchKeyword) {
        $searchConditions = [];

        // جستجو در فیلد expertise_field و phone برای همه جداول
        $searchConditions[] = "{$fields['expertise_field']} LIKE :keyword";
        $searchConditions[] = "phone LIKE :keyword";

        // جستجو بر اساس اسم و فامیلی در جداول خاص
        if (in_array($table, $nameSearchTables)) {
            if (count($nameParts) == 2) {
                // اگر دو بخش وارد شده (اسم و فامیلی)
                $searchConditions[] = "(first_name LIKE :first_name AND last_name LIKE :last_name)";
            } else {
                // اگر یک بخش وارد شده (فقط اسم یا فقط فامیلی)
                $searchConditions[] = "(first_name LIKE :keyword OR last_name LIKE :keyword)";
            }
        }

        // جستجو بر اساس name در جداول خاص
        if (in_array($table, $nameOnlyTables)) {
            $searchConditions[] = "name LIKE :keyword";
        }

        $whereClause .= " AND (" . implode(" OR ", $searchConditions) . ")";
    }

    $unionQueries[] = "
        SELECT '$table' AS source_table,
               {$fields['picture']} AS picture,
               {$fields['first_name']} AS first_name,
               {$fields['last_name']} AS last_name,
               province,
               city,
               phone,
               {$fields['expertise_field']} AS expertise_field,
               similar_words
        FROM $table
        WHERE $whereClause
    ";
}

$finalQuery = implode(" UNION ALL ", $unionQueries) . " LIMIT :limit OFFSET :offset";

// کوئری شمارش تعداد افراد در هر دسته‌بندی
$categoryCountQueries = [];
foreach ($selectedTables as $table) {
    $fields = $tableFields[$table];
    $whereClause = "1=1";

    // افزودن شرط‌های فیلتر
    if (!empty($filterConditions)) {
        $whereClause .= " AND " . implode(" AND ", $filterConditions);
    }

    // افزودن شرط جستجو (اگر وجود دارد)
    if ($searchKeyword) {
        $searchConditions = [];

        // جستجو در فیلد expertise_field و phone برای همه جداول
        $searchConditions[] = "{$fields['expertise_field']} LIKE :keyword";
        $searchConditions[] = "phone LIKE :keyword";

        // جستجو بر اساس اسم و فامیلی در جداول خاص
        if (in_array($table, $nameSearchTables)) {
            if (count($nameParts) == 2) {
                // اگر دو بخش وارد شده (اسم و فامیلی)
                $searchConditions[] = "(first_name LIKE :first_name AND last_name LIKE :last_name)";
            } else {
                // اگر یک بخش وارد شده (فقط اسم یا فقط فامیلی)
                $searchConditions[] = "(first_name LIKE :keyword OR last_name LIKE :keyword)";
            }
        }

        // جستجو بر اساس name در جداول خاص
        if (in_array($table, $nameOnlyTables)) {
            $searchConditions[] = "name LIKE :keyword";
        }

        $whereClause .= " AND (" . implode(" OR ", $searchConditions) . ")";
    }

    $categoryCountQueries[] = "
        SELECT '$table' AS category, COUNT(*) AS count
        FROM $table
        WHERE $whereClause
    ";
}

$categoryCountQuery = implode(" UNION ALL ", $categoryCountQueries);

// کوئری شمارش کل افراد
$totalCountQuery = "
    SELECT SUM(count) AS total_count
    FROM (
        " . implode(" UNION ALL ", array_map(function($table) use ($filterConditions, $searchKeyword, $tableFields, $nameSearchTables, $nameOnlyTables, $nameParts) {
            $fields = $tableFields[$table];
            $whereClause = "1=1";

            // افزودن شرط‌های فیلتر
            if (!empty($filterConditions)) {
                $whereClause .= " AND " . implode(" AND ", $filterConditions);
            }

            // افزودن شرط جستجو (اگر وجود دارد)
            if ($searchKeyword) {
                $searchConditions = [];

                // جستجو در فیلد expertise_field و phone برای همه جداول
                $searchConditions[] = "{$fields['expertise_field']} LIKE :keyword";
                $searchConditions[] = "phone LIKE :keyword";

                // جستجو بر اساس اسم و فامیلی در جداول خاص
                if (in_array($table, $nameSearchTables)) {
                    if (count($nameParts) == 2) {
                        // اگر دو بخش وارد شده (اسم و فامیلی)
                        $searchConditions[] = "(first_name LIKE :first_name AND last_name LIKE :last_name)";
                    } else {
                        // اگر یک بخش وارد شده (فقط اسم یا فقط فامیلی)
                        $searchConditions[] = "(first_name LIKE :keyword OR last_name LIKE :keyword)";
                    }
                }

                // جستجو بر اساس name در جداول خاص
                if (in_array($table, $nameOnlyTables)) {
                    $searchConditions[] = "name LIKE :keyword";
                }

                $whereClause .= " AND (" . implode(" OR ", $searchConditions) . ")";
            }

            return "SELECT COUNT(*) AS count FROM $table WHERE $whereClause";
        }, $selectedTables)) . "
    ) AS total_counts
";

try {
    // اجرای کوئری شمارش کل
    $stmtTotalCount = $conn->prepare($totalCountQuery);
    foreach ($filters as $key => $value) {
        $stmtTotalCount->bindValue($key, $value);
    }
    if ($searchKeyword) {
        $stmtTotalCount->bindValue(':keyword', "%$searchKeyword%");
        if (count($nameParts) == 2) {
            $stmtTotalCount->bindValue(':first_name', "%{$nameParts[0]}%");
            $stmtTotalCount->bindValue(':last_name', "%{$nameParts[1]}%");
        }
    }
    $stmtTotalCount->execute();
    $totalCount = $stmtTotalCount->fetch(PDO::FETCH_ASSOC);

    // اگر هیچ نتیجه‌ای وجود نداشت
    if ($totalCount['total_count'] == 0) {
        echo json_encode([
            'resumes' => [],
            'category_counts' => [],
            'total_count' => 0,
            'current_page' => $page,
            'total_pages' => 0,
            'items_per_page' => 0
        ], JSON_UNESCAPED_UNICODE | JSON_THROW_ON_ERROR);
        return;
    }

    // محاسبه تعداد کل صفحات
    $totalPages = ceil($totalCount['total_count'] / $limit);

    // اگر صفحه درخواستی بیشتر از تعداد کل صفحات باشد، صفحه‌ی آخر را برگردان
    if ($page > $totalPages) {
        $page = $totalPages;
    }

    // تنظیم limit برای آخرین صفحه
    $currentLimit = $limit;
    if ($page == $totalPages) {
        $remainingItems = $totalCount['total_count'] - (($page - 1) * $limit);
        $currentLimit = max($remainingItems, 0); // اطمینان از مثبت بودن مقدار
    }

    // اجرای کوئری اصلی با پینگینگ
    $stmt = $conn->prepare($finalQuery);
    foreach ($filters as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    if ($searchKeyword) {
        $stmt->bindValue(':keyword', "%$searchKeyword%");
        if (count($nameParts) == 2) {
            $stmt->bindValue(':first_name', "%{$nameParts[0]}%");
            $stmt->bindValue(':last_name', "%{$nameParts[1]}%");
        }
    }
    $stmt->bindValue(':limit', $currentLimit, PDO::PARAM_INT);
    $stmt->bindValue(':offset', ($page - 1) * $limit, PDO::PARAM_INT);
    $stmt->execute();
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // اجرای کوئری شمارش دسته‌بندی‌ها
    $stmtCount = $conn->prepare($categoryCountQuery);
    foreach ($filters as $key => $value) {
        $stmtCount->bindValue($key, $value);
    }
    if ($searchKeyword) {
        $stmtCount->bindValue(':keyword', "%$searchKeyword%");
        if (count($nameParts) == 2) {
            $stmtCount->bindValue(':first_name', "%{$nameParts[0]}%");
            $stmtCount->bindValue(':last_name', "%{$nameParts[1]}%");
        }
    }
    $stmtCount->execute();
    $categoryCounts = $stmtCount->fetchAll(PDO::FETCH_ASSOC);

    // ارسال پاسخ
    echo json_encode([
        'resumes' => $results,
        'category_counts' => $categoryCounts,
        'total_count' => $totalCount['total_count'],
        'current_page' => $page,
        'total_pages' => $totalPages,
        'items_per_page' => $currentLimit
    ], JSON_UNESCAPED_UNICODE | JSON_THROW_ON_ERROR);

} catch (Exception $e) {
    $utility->handleError(500, [
        'user_message' => "خطایی در اجرای جستجو رخ داد. لطفاً مجدداً تلاش کنید.",
        'developer_message' => "Query execution error: " . $e->getMessage()
    ]);
}

// تابع اعتبارسنجی ورودی
function sanitizeInput($input) {
    return htmlspecialchars(strip_tags(trim($input)));
}
?>