<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';

use \Firebase\JWT\JWT;
use \Firebase\JWT\ExpiredException;

$utility = new Utility();

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();

if (!$encodedString) {
    $utility->handleError(401, "توکن ارائه نشده است.");
    exit();
}

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));

if (
    !empty($data->full_name) &&
    !empty($data->phone) &&
    !empty($data->user_name) &&
    !empty($data->password) &&
    !empty($data->access_level)
) {
    try {
        // بررسی اعتبار توکن
        $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
        $decodedPayload = (array) $decodedToken->data;

        if (!isset($decodedPayload['access_level']) || $decodedPayload['access_level'] !== 'manager') {
            $utility->handleError(403, "شما دسترسی لازم برای این عملیات را ندارید.");
            exit();
        }

        // اتصال به دیتابیس
        $database = new Database();
        $conn = $database->getConnection();

        // شروع تراکنش
        $conn->beginTransaction();

        // بررسی تکراری نبودن نام کاربری یا شماره تلفن
        $checkQuery = "SELECT id FROM admins WHERE user_name = :user_name OR phone = :phone LIMIT 1";
        $checkStmt = $conn->prepare($checkQuery);
        $checkStmt->bindValue(":user_name", $data->user_name, PDO::PARAM_STR);
        $checkStmt->bindValue(":phone", $data->phone, PDO::PARAM_STR);
        $checkStmt->execute();

        if ($checkStmt->rowCount() > 0) {
            $utility->handleError(409, "نام کاربری یا شماره تلفن قبلاً ثبت شده است.");
            $conn->rollBack();
            exit();
        }

        // بررسی تکراری نبودن referral_code (اگر وجود دارد)
        if (!empty($data->referral_code)) {
            $checkReferralQuery = "SELECT id FROM admins WHERE referral_code = :referral_code LIMIT 1";
            $checkReferralStmt = $conn->prepare($checkReferralQuery);
            $checkReferralStmt->bindValue(":referral_code", $data->referral_code, PDO::PARAM_STR);
            $checkReferralStmt->execute();

            if ($checkReferralStmt->rowCount() > 0) {
                $utility->handleError(409, "کد معرف قبلاً ثبت شده است.");
                $conn->rollBack();
                exit();
            }
        }

        // هش کردن رمز عبور
        $hashedPassword = password_hash($data->password, PASSWORD_BCRYPT);

        // افزودن ادمین جدید
        $insertQuery = "INSERT INTO admins (full_name, phone, user_name, password, access_level, referral_code) 
                        VALUES (:full_name, :phone, :user_name, :password, :access_level, :referral_code)";
        $insertStmt = $conn->prepare($insertQuery);

        $insertStmt->bindValue(":full_name", $data->full_name, PDO::PARAM_STR);
        $insertStmt->bindValue(":phone", $data->phone, PDO::PARAM_STR);
        $insertStmt->bindValue(":user_name", $data->user_name, PDO::PARAM_STR);
        $insertStmt->bindValue(":password", $hashedPassword, PDO::PARAM_STR);
        $insertStmt->bindValue(":access_level", $data->access_level, PDO::PARAM_STR);
        $insertStmt->bindValue(":referral_code", $data->referral_code ?? null, PDO::PARAM_STR);

        if ($insertStmt->execute()) {
            $conn->commit();
            http_response_code(201);
            echo json_encode(["message" => "ادمین با موفقیت اضافه شد."], JSON_UNESCAPED_UNICODE);
        } else {
            $conn->rollBack();
            $utility->handleError(500, "خطا در افزودن ادمین جدید.");
        }
    } catch (ExpiredException $e) {
        $utility->handleError(401, "توکن منقضی شده است.");
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "توکن نامعتبر است.");
    } catch (Exception $e) {
        $conn->rollBack();
        $utility->handleError(500, "خطایی در سرور رخ داده است.");
    }
} else {
    $utility->handleError(400, "لطفاً تمامی اطلاعات لازم را وارد کنید.");
}
?>