<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: DELETE"); // استفاده از متد DELETE

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';

use \Firebase\JWT\JWT;
use \Firebase\JWT\ExpiredException;

$utility = new Utility();

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();

if (!$encodedString) {
    $utility->handleError(401, "توکن ارائه نشده است.");
    exit();
}

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));

if (!empty($data->id)) { // آیدی کاربر برای حذف الزامی است
    try {
        // بررسی اعتبار توکن
        $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
        $decodedPayload = (array) $decodedToken->data;

        if (!isset($decodedPayload['access_level']) || $decodedPayload['access_level'] !== 'manager') {
            $utility->handleError(403, "شما دسترسی لازم برای این عملیات را ندارید.");
            exit();
        }

        // اتصال به دیتابیس
        $database = new Database();
        $conn = $database->getConnection();

        // شروع تراکنش
        $conn->beginTransaction();

        // بررسی وجود کاربر با آیدی داده شده
        $checkQuery = "SELECT id FROM admins WHERE id = :id LIMIT 1";
        $checkStmt = $conn->prepare($checkQuery);
        $checkStmt->bindValue(":id", $data->id, PDO::PARAM_INT);
        $checkStmt->execute();

        if ($checkStmt->rowCount() === 0) {
            $utility->handleError(404, "کاربری با این آیدی یافت نشد.");
            $conn->rollBack();
            exit();
        }

        // حذف کاربر
        $deleteQuery = "DELETE FROM admins WHERE id = :id";
        $deleteStmt = $conn->prepare($deleteQuery);
        $deleteStmt->bindValue(":id", $data->id, PDO::PARAM_INT);

        if ($deleteStmt->execute()) {
            $conn->commit();
            http_response_code(200);
            echo json_encode(["message" => "کاربر با موفقیت حذف شد."], JSON_UNESCAPED_UNICODE);
        } else {
            $conn->rollBack();
            $utility->handleError(500, "خطا در حذف کاربر.");
        }
    } catch (ExpiredException $e) {
        $utility->handleError(401, "توکن منقضی شده است.");
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "توکن نامعتبر است.");
    } catch (Exception $e) {
        $conn->rollBack();
        $utility->handleError(500, "خطایی در سرور رخ داده است.");
    }
} else {
    $utility->handleError(400, "لطفاً آیدی کاربر را وارد کنید.");
}
?>