<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Allow-Headers: Content-Type, Authorization");
header("Access-Control-Allow-Origin: *");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';

use Firebase\JWT\JWT;
use Firebase\JWT\ExpiredException;
use Firebase\JWT\SignatureInvalidException;

$utility = new Utility();
$headers = getallheaders();
$authHeader = $headers['Authorization'] ?? null;

if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
    $utility->handleError(401, "توکن احراز هویت ارائه نشده است.");
    exit();
}

$jwt = $matches[1];

try {
    $decoded = JWT::decode($jwt, JWT_KEY, ['HS256']);
    if (!isset($decoded->data->access_level) || !in_array($decoded->data->access_level, ['manager', '1'])) {
        $utility->handleError(403, "دسترسی غیرمجاز.");
        exit();
    }

    $database = new Database();
    $conn = $database->getConnection();
    $data = json_decode(file_get_contents("php://input"), true);

    if (empty($data['phone']) || empty($data['table_name'])) {
        $utility->handleError(400, "پارامترهای ضروری ارسال نشده است.");
        exit();
    }

    $phone = htmlspecialchars(strip_tags($data['phone']));
    $tableName = htmlspecialchars(strip_tags($data['table_name']));

    $allowedTables = ['person_resume', 'student_resume', 'teacher_resume', 'transportation_resume', 'club_resume', 'company_resume', 'school_resume', 'store_resume', 'workshop_resume'];
    if (!in_array($tableName, $allowedTables)) {
        $utility->handleError(400, "نوع رزومه نامعتبر.");
        exit();
    }

    $checkQuery = "SELECT resume_id, use_referral_code FROM $tableName WHERE phone = :phone";
    $checkStmt = $conn->prepare($checkQuery);
    $checkStmt->bindParam(':phone', $phone);
    $checkStmt->execute();
    $resumeData = $checkStmt->fetch(PDO::FETCH_ASSOC);

    if (!$resumeData) {
        $utility->handleError(404, "رزومه یافت نشد.");
        exit();
    }

    $conn->beginTransaction();
    $deleteQuery = "DELETE FROM $tableName WHERE phone = :phone";
    $deleteStmt = $conn->prepare($deleteQuery);
    $deleteStmt->bindParam(':phone', $phone);
    $deleteStmt->execute();

    if (!empty($resumeData['use_referral_code'])) {
        $referralCode = $resumeData['use_referral_code'];
        $updateAdminQuery = "UPDATE admins SET point = point - 10, user_count = user_count - 1 WHERE referral_code = :referral_code AND point >= 10 AND user_count > 0";
        $updateAdminStmt = $conn->prepare($updateAdminQuery);
        $updateAdminStmt->bindParam(':referral_code', $referralCode);

        if (!$updateAdminStmt->execute()) {
            $conn->rollBack();
            $utility->handleError(500, "خطا در به‌روزرسانی اطلاعات ادمین.");
            exit();
        }
    }

    $conn->commit();
    echo json_encode([
        'success' => true,
        'message' => 'رزومه با موفقیت حذف شد',
        'data' => [
            'deleted_phone' => $phone,
            'table' => $tableName,
            'referral_code' => $resumeData['use_referral_code'] ?? 'ندارد',
            'admin_point_deducted' => isset($resumeData['use_referral_code']) ? true : false
        ]
    ], JSON_UNESCAPED_UNICODE);

} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (SignatureInvalidException $e) {
    $utility->handleError(401, "امضای توکن نامعتبر است.");
} catch (Exception $e) {
    $conn->rollBack();
    $utility->handleError(500, "خطای سرور: " . $e->getMessage());
}
?>
