<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';

use Firebase\JWT\JWT;
use Firebase\JWT\ExpiredException;
use Firebase\JWT\SignatureInvalidException;

$utility = new Utility();

// دریافت توکن از هدر Authorization
$headers = getallheaders();
$authHeader = $headers['Authorization'] ?? null;

// بررسی فرمت توکن (مطابق با endpoint لاگین)
if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
    $utility->handleError(401, "توکن احراز هویت ارائه نشده است.");
    exit();
}

$jwt = $matches[1];

try {
    // رمزگشایی توکن با JWT_KEY از core.php (مطابق با لاگین)
    $decoded = JWT::decode($jwt, JWT_KEY, ['HS256']);

    // بررسی ساختار توکن (مطابق با لاگین)
    if (
        !isset($decoded->data->access_level) ||
        $decoded->data->access_level !== 'manager'
    ) {
        $utility->handleError(403, "شما دسترسی لازم برای این عملیات را ندارید.");
        exit();
    }

    // دریافت آیدی ادمین از پارامتر GET
    if (!isset($_GET['id']) || empty($_GET['id'])) {
        $utility->handleError(400, "آیدی ادمین ارائه نشده است.");
        exit();
    }

    $admin_id = $_GET['id'];

    // اتصال به دیتابیس
    $database = new Database();
    $conn = $database->getConnection();

    // دریافت اطلاعات ادمین بر اساس آیدی
    $query = "SELECT 
                id, 
                full_name, 
                phone, 
                user_name, 
                access_level, 
                referral_code,
                point,
                user_count
              FROM admins
              WHERE id = :id";
    
    $stmt = $conn->prepare($query);
    $stmt->bindParam(':id', $admin_id, PDO::PARAM_INT);
    $stmt->execute();

    // مدیریت پاسخ
    if ($stmt->rowCount() > 0) {
        $admin = $stmt->fetch(PDO::FETCH_ASSOC);
        
        echo json_encode([
            "message" => "اطلاعات ادمین با موفقیت دریافت شد.",
            "data" => $admin
        ], JSON_UNESCAPED_UNICODE);
    } else {
        $utility->handleError(404, "ادمین با آیدی مشخص شده یافت نشد.");
    }

} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (SignatureInvalidException $e) {
    $utility->handleError(401, "امضای توکن نامعتبر است.");
} catch (Exception $e) {
    $utility->handleError(500, "خطای سرور: " . $e->getMessage());
}
?>