<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, [
        'user_message' => "متأسفانه ارتباط با پایگاه داده برقرار نشد. لطفاً مجدداً تلاش کنید.",
        'developer_message' => "Database connection error: " . $e->getMessage()
    ]);
    die();
}

// دریافت و اعتبارسنجی پارامتر use_referral_code
$use_referral_code = isset($_GET['use_referral_code']) ? sanitizeInput($_GET['use_referral_code']) : null;
if (empty($use_referral_code)) {
    $utility->handleError(400, [
        'user_message' => "لطفاً کد معرف را وارد کنید.",
        'developer_message' => "use_referral_code parameter is missing."
    ]);
    die();
}

// تعریف جدول‌های رزومه و فیلدهای مربوطه (با اضافه شدن phone)
$resumeTables = [
    'person_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'skills',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'student_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'student_field',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'teacher_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'teacher_field',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'transportation_resume' => [
        'picture' => 'profile_picture',
        'first_name' => 'first_name',
        'last_name' => 'last_name',
        'expertise_field' => 'car_category',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'club_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'sport_fields',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'company_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'company_category',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'school_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'educational_fields',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'store_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'store_category',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ],
    'workshop_resume' => [
        'picture' => 'COALESCE(logo_picture, \'\')',
        'first_name' => 'name',
        'last_name' => '\'\'',
        'expertise_field' => 'workshop_category',
        'mobile_number' => 'phone' // فیلد شماره موبایل با نام phone
    ]
];

// ساخت کوئری‌های UNION برای جستجو در تمام جدول‌های رزومه
$unionQueries = [];
foreach ($resumeTables as $table => $fields) {
    $unionQueries[] = "
        SELECT '$table' AS source_table,
               {$fields['picture']} AS picture,
               {$fields['first_name']} AS first_name,
               {$fields['last_name']} AS last_name,
               {$fields['expertise_field']} AS expertise_field,
               {$fields['mobile_number']} AS mobile_number
        FROM $table
        WHERE use_referral_code = :use_referral_code
    ";
}

// کوئری نهایی
$finalQuery = implode(" UNION ALL ", $unionQueries);

try {
    // اجرای کوئری
    $stmt = $conn->prepare($finalQuery);
    $stmt->bindValue(":use_referral_code", $use_referral_code, PDO::PARAM_STR);
    $stmt->execute();
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if ($results) {
        // ارسال پاسخ موفق
        echo json_encode([
            'success' => true,
            'data' => $results
        ], JSON_UNESCAPED_UNICODE | JSON_THROW_ON_ERROR);
    } else {
        // اگر هیچ نتیجه‌ای یافت نشد
        echo json_encode([
            'success' => false,
            'message' => "هیچ اطلاعاتی با کد معرف داده شده یافت نشد."
        ], JSON_UNESCAPED_UNICODE | JSON_THROW_ON_ERROR);
    }
} catch (Exception $e) {
    $utility->handleError(500, [
        'user_message' => "خطایی در اجرای درخواست رخ داد. لطفاً مجدداً تلاش کنید.",
        'developer_message' => "Query execution error: " . $e->getMessage()
    ]);
}

// تابع اعتبارسنجی ورودی
function sanitizeInput($input) {
    return htmlspecialchars(strip_tags(trim($input)));
}