<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET");

// فایل‌های مورد نیاز
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';

use \Firebase\JWT\JWT;
use \Firebase\JWT\ExpiredException;

$utility = new Utility();

/**
 * تابع تبدیل اعداد انگلیسی به فارسی
 */
function convertToPersianNumbers($number) {
    $persianDigits = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    $englishDigits = range(0, 9);
    return str_replace($englishDigits, $persianDigits, $number);
}

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();
if (!$encodedString) {
    $utility->handleError(401, "توکن ارائه نشده است.");
    exit();
}

try {
    // بررسی اعتبار توکن
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $decodedPayload = (array) $decodedToken->data;

    // سطوح دسترسی مجاز
    $allowedAccessLevels = ['manager', '1'];

    // بررسی دسترسی
    if (!isset($decodedPayload['access_level']) || !in_array($decodedPayload['access_level'], $allowedAccessLevels)) {
        $utility->handleError(403, "شما دسترسی لازم برای این عملیات را ندارید.");
        exit();
    }

    // اتصال به دیتابیس
    $database = new Database();
    $conn = $database->getConnection();

    // استعلام SQL برای دریافت تمام تراکنش‌ها شامل account_type
    $selectQuery = "SELECT 
                        id,
                        point,
                        balance,
                        card_number,
                        card_name,
                        bank_name,
                        date_request,
                        date_payment,
                        time_payment,
                        full_name,
                        phone,
                        referral_code,
                        payment_status,
                        tracking_code,
                        description,
                        account_type
                    FROM transaction";
    $stmt = $conn->prepare($selectQuery);
    $stmt->execute();

    // دریافت نتایج
    $transactions = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if (!$transactions) {
        http_response_code(200);
        echo json_encode(["message" => "هیچ تراکنشی یافت نشد."], JSON_UNESCAPED_UNICODE);
        exit();
    }

    // فرمت‌بندی مبالغ (balance) به فارسی و اضافه کردن "ریال"
    foreach ($transactions as &$transaction) {
        if (isset($transaction['balance'])) {
            // فرمت‌بندی مبلغ با ویرگول بین هر سه رقم
            $formattedBalance = number_format($transaction['balance'], 0, '', ',');
            // تبدیل اعداد به فارسی
            $persianFormattedBalance = convertToPersianNumbers($formattedBalance);
            // اضافه کردن "ریال" به مقدار
            $transaction['formatted_balance'] = $persianFormattedBalance . ' ریال';
        }
    }

    // پاسخ موفقیت‌آمیز
    http_response_code(200);
    echo json_encode(["transactions" => $transactions], JSON_UNESCAPED_UNICODE);

} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (\Firebase\JWT\SignatureInvalidException $e) {
    $utility->handleError(401, "توکن نامعتبر است.");
} catch (Exception $e) {
    $utility->handleError(500, "خطایی در سرور رخ داده است.");
}
?>
