<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));

if (!empty($data->username) && !empty($data->password)) {
    try {
        // اتصال به دیتابیس
        $database = new Database();
        $conn = $database->getConnection();

        // بررسی یوزرنیم
        $query = "SELECT * FROM admins WHERE user_name = :username LIMIT 1";
        $stmt = $conn->prepare($query);
        $stmt->bindParam(":username", $data->username, PDO::PARAM_STR);
        $stmt->execute();

        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($row) {
            // بررسی رمز عبور هش شده
            if (password_verify($data->password, $row['password'])) {
                // یوزرنیم و پسورد صحیح است، ایجاد توکن JWT
                $accessLevel = $row['access_level']; 
                $referral_code = $row['referral_code'];

                $token = array(
                    "iss" => ISSUER,
                    "aud" => AUDIENCE,
                    "iat" => time(),
                    "exp" => time() + EXPIRATION_TIME, // اعتبار توکن از core.php
                    "data" => array(
                        "id" => $row['id'],
                        "username" => $row['user_name'],
                        "access_level" => $accessLevel
                    )
                );

                $jwt = JWT::encode($token, JWT_KEY);

                http_response_code(200);
                echo json_encode(array(
                    "message" => "ورود موفقیت‌آمیز بود.",
                    "jwt" => $jwt,
                    "access_level" => $accessLevel ,
                    "referral_code"=>$referral_code
                ), JSON_UNESCAPED_UNICODE);
            } else {
                // رمز عبور اشتباه است
                $utility->handleError(401, "نام کاربری یا رمز عبور اشتباه است.");
            }
        } else {
            // نام کاربری پیدا نشد
            $utility->handleError(401, "نام کاربری یا رمز عبور اشتباه است.");
        }
    } catch (Exception $e) {
        // خطای سرور
        $utility->handleError(500, "خطایی در سرور رخ داده است: " . $e->getMessage());
    }
} else {
    // اطلاعات ورودی ناقص است
    $utility->handleError(400, "لطفاً تمامی اطلاعات لازم را وارد کنید.");
}
?>