<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';

use Firebase\JWT\JWT;
use Firebase\JWT\ExpiredException;
use Firebase\JWT\SignatureInvalidException;

$utility = new Utility();

// دریافت توکن از هدر Authorization
$headers = getallheaders();
$authHeader = $headers['Authorization'] ?? null;

// بررسی فرمت توکن
if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
    $utility->handleError(401, "توکن احراز هویت ارائه نشده است.");
    exit();
}

$jwt = $matches[1];

try {
    // رمزگشایی توکن
    $decoded = JWT::decode($jwt, JWT_KEY, ['HS256']);

    // بررسی ساختار توکن
    if (
        !isset($decoded->data->id) ||
        !isset($decoded->data->username) ||
        !isset($decoded->data->access_level)
    ) {
        $utility->handleError(401, "ساختار توکن نامعتبر است.");
        exit();
    }

    // اتصال به دیتابیس
    $database = new Database();
    $conn = $database->getConnection();

    // کوئری اصلی برای دریافت اطلاعات کاربر
    $query = "SELECT 
                id, 
                full_name, 
                phone, 
                user_name, 
                access_level, 
                referral_code,
                user_count,
                	point
              FROM admins 
              WHERE user_name = :username
              LIMIT 1";

    $stmt = $conn->prepare($query);
    $stmt->bindParam(':username', $decoded->data->username);
    $stmt->execute();

    // بررسی وجود کاربر
    if ($stmt->rowCount() === 0) {
        $utility->handleError(404, "کاربر یافت نشد.");
        exit();
    }

    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    // حذف فیلدهای حساس
    unset($user['password']);
    unset($user['reset_token']);

    // پاسخ JSON با داده‌های تکمیل شده
    echo json_encode([
        "message" => "اطلاعات پروفایل با موفقیت دریافت شد",
        "data" => [
            "user_info" => $user
        ]
    ], JSON_UNESCAPED_UNICODE);

} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (SignatureInvalidException $e) {
    $utility->handleError(401, "امضای توکن نامعتبر است.");
} catch (Exception $e) {
    $utility->handleError(500, "خطای سرور: " . $e->getMessage());
}
?>