<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: PUT"); // تغییر به PUT برای آپدیت

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';

use \Firebase\JWT\JWT;
use \Firebase\JWT\ExpiredException;

$utility = new Utility();

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();

if (!$encodedString) {
    $utility->handleError(401, "توکن ارائه نشده است.");
    exit();
}

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));

if (
    !empty($data->id) && // آیدی کاربر برای آپدیت الزامی است
    (!empty($data->full_name) ||
     !empty($data->phone) ||
     !empty($data->user_name) ||
     !empty($data->password) ||
     !empty($data->access_level))
) {
    try {
        // بررسی اعتبار توکن
        $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
        $decodedPayload = (array) $decodedToken->data;

        if (!isset($decodedPayload['access_level']) || $decodedPayload['access_level'] !== 'manager') {
            $utility->handleError(403, "شما دسترسی لازم برای این عملیات را ندارید.");
            exit();
        }

        // اتصال به دیتابیس
        $database = new Database();
        $conn = $database->getConnection();

        // شروع تراکنش
        $conn->beginTransaction();

        // بررسی وجود کاربر با آیدی داده شده
        $checkQuery = "SELECT id FROM admins WHERE id = :id LIMIT 1";
        $checkStmt = $conn->prepare($checkQuery);
        $checkStmt->bindValue(":id", $data->id, PDO::PARAM_INT);
        $checkStmt->execute();

        if ($checkStmt->rowCount() === 0) {
            $utility->handleError(404, "کاربری با این آیدی یافت نشد.");
            $conn->rollBack();
            exit();
        }

        // بررسی تکراری نبودن نام کاربری یا شماره تلفن (فقط اگر تغییر کرده باشند)
        if (!empty($data->user_name) || !empty($data->phone)) {
            $checkDuplicateQuery = "SELECT id FROM admins WHERE (user_name = :user_name OR phone = :phone) AND id != :id LIMIT 1";
            $checkDuplicateStmt = $conn->prepare($checkDuplicateQuery);
            $checkDuplicateStmt->bindValue(":user_name", $data->user_name ?? '', PDO::PARAM_STR);
            $checkDuplicateStmt->bindValue(":phone", $data->phone ?? '', PDO::PARAM_STR);
            $checkDuplicateStmt->bindValue(":id", $data->id, PDO::PARAM_INT);
            $checkDuplicateStmt->execute();

            if ($checkDuplicateStmt->rowCount() > 0) {
                $utility->handleError(409, "نام کاربری یا شماره تلفن قبلاً ثبت شده است.");
                $conn->rollBack();
                exit();
            }
        }

        // بررسی تکراری نبودن referral_code (اگر وجود دارد و تغییر کرده است)
        if (!empty($data->referral_code)) {
            $checkReferralQuery = "SELECT id FROM admins WHERE referral_code = :referral_code AND id != :id LIMIT 1";
            $checkReferralStmt = $conn->prepare($checkReferralQuery);
            $checkReferralStmt->bindValue(":referral_code", $data->referral_code, PDO::PARAM_STR);
            $checkReferralStmt->bindValue(":id", $data->id, PDO::PARAM_INT);
            $checkReferralStmt->execute();

            if ($checkReferralStmt->rowCount() > 0) {
                $utility->handleError(409, "کد معرف قبلاً ثبت شده است.");
                $conn->rollBack();
                exit();
            }
        }

        // هش کردن رمز عبور (اگر تغییر کرده است)
        $hashedPassword = null;
        if (!empty($data->password)) {
            $hashedPassword = password_hash($data->password, PASSWORD_BCRYPT);
        }

        // آپدیت اطلاعات کاربر
        $updateQuery = "UPDATE admins SET 
                        full_name = COALESCE(:full_name, full_name), 
                        phone = COALESCE(:phone, phone), 
                        user_name = COALESCE(:user_name, user_name), 
                        password = COALESCE(:password, password), 
                        access_level = COALESCE(:access_level, access_level), 
                        referral_code = COALESCE(:referral_code, referral_code) 
                        WHERE id = :id";
        $updateStmt = $conn->prepare($updateQuery);

        $updateStmt->bindValue(":full_name", $data->full_name ?? null, PDO::PARAM_STR);
        $updateStmt->bindValue(":phone", $data->phone ?? null, PDO::PARAM_STR);
        $updateStmt->bindValue(":user_name", $data->user_name ?? null, PDO::PARAM_STR);
        $updateStmt->bindValue(":password", $hashedPassword ?? null, PDO::PARAM_STR);
        $updateStmt->bindValue(":access_level", $data->access_level ?? null, PDO::PARAM_STR);
        $updateStmt->bindValue(":referral_code", $data->referral_code ?? null, PDO::PARAM_STR);
        $updateStmt->bindValue(":id", $data->id, PDO::PARAM_INT);

        if ($updateStmt->execute()) {
            $conn->commit();
            http_response_code(200);
            echo json_encode(["message" => "اطلاعات کاربر با موفقیت آپدیت شد."], JSON_UNESCAPED_UNICODE);
        } else {
            $conn->rollBack();
            $utility->handleError(500, "خطا در آپدیت اطلاعات کاربر.");
        }
    } catch (ExpiredException $e) {
        $utility->handleError(401, "توکن منقضی شده است.");
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "توکن نامعتبر است.");
    } catch (Exception $e) {
        $conn->rollBack();
        $utility->handleError(500, "خطایی در سرور رخ داده است.");
    }
} else {
    $utility->handleError(400, "لطفاً حداقل یک فیلد برای آپدیت و آیدی کاربر را وارد کنید.");
}
?>