<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';

use \Firebase\JWT\JWT;
use \Firebase\JWT\ExpiredException;

$utility = new Utility();

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();

if (!$encodedString) {
    $utility->handleError(401, "توکن ارائه نشده است.");
    exit();
}

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));

// اعتبارسنجی داده‌های ورودی
if (empty($data->referral_code)) {
    $utility->handleError(400, "لطفاً کد معرف را وارد کنید.");
    exit();
}

try {
    // بررسی اعتبار توکن
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $decodedPayload = (array) $decodedToken->data;

    // سطوح دسترسی مجاز
    $allowedAccessLevels = ['manager', '1', '2', '3'];

    // بررسی دسترسی
    if (!isset($decodedPayload['access_level']) || !in_array($decodedPayload['access_level'], $allowedAccessLevels)) {
        $utility->handleError(403, "شما دسترسی لازم برای این عملیات را ندارید.");
        exit();
    }

    // اتصال به دیتابیس
    $database = new Database();
    $conn = $database->getConnection();

    // شروع تراکنش
    $conn->beginTransaction();

    // به‌روزرسانی user_count و point
    $updateQuery = "UPDATE admins 
                    SET user_count = user_count + 1, 
                        point = point + 10
                    WHERE referral_code = :referral_code";
    $updateStmt = $conn->prepare($updateQuery);

    $updateStmt->bindValue(":referral_code", $data->referral_code, PDO::PARAM_STR);

    if ($updateStmt->execute()) {
        // بررسی تعداد ردیف‌های به‌روزرسانی شده
        if ($updateStmt->rowCount() > 0) {
            $conn->commit();
            http_response_code(200);
            echo json_encode(["message" => "۱۰ امتیاز دریافت کردید."], JSON_UNESCAPED_UNICODE);
        } else {
            $conn->rollBack();
            $utility->handleError(404, "ادمینی با کد معرف داده شده یافت نشد.");
        }
    } else {
        $conn->rollBack();
        $utility->handleError(500, "خطا در به‌روزرسانی اطلاعات ادمین.");
    }
} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (\Firebase\JWT\SignatureInvalidException $e) {
    $utility->handleError(401, "توکن نامعتبر است.");
} catch (Exception $e) {
    $conn->rollBack();
    $utility->handleError(500, "خطایی در سرور رخ داده است.");
}
?>