<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: PUT");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "Unable to connect to the database: " . $e->getMessage());
    die();
}

$resume = new Resume($conn);
$data = json_decode(file_get_contents("php://input"));

if (!isset($data->user_phone) || empty($data->user_phone)) {
    $utility->handleError(400, "User phone is required.");
    die();
}

$phone = htmlspecialchars(strip_tags($data->user_phone));

// دریافت و بررسی توکن
$encodedString = $utility->getToken();
$decodedPayload = null;

if ($encodedString) {
    try {
        $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
        $decodedPayload = (array)$decodedToken->data;

        if (!isset($decodedPayload['user_phone'])) {
            $utility->handleError(401, "Phone number not found in the token.");
            die();
        }

        if ($decodedPayload['user_phone'] !== $data->user_phone) {
            $utility->handleError(403, "The phone number in the token does not match the provided phone number.");
            die();
        }

    } catch (\Firebase\JWT\ExpiredException $e) {
        $utility->handleError(401, "JWT token has expired.");
        die();
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "JWT signature is invalid.");
        die();
    } catch (Exception $e) {
        $utility->handleError(401, "Invalid JWT token.");
        die();
    }
} else {
    $utility->handleError(400, "No JWT token found in the Authorization header.");
    die();
}

$resume->phone = $utility->validateInput($data->user_phone, 'string');

if (strlen($phone) > 15) {
    $utility->handleError(400, "Phone number cannot be longer than 15 characters.");
    die();
}

if (!$resume->phoneExists1($phone, "users")) {
    $utility->handleError(404, "User with this phone number not found!");
    die();
}

if (!$resume->phoneExists1($phone, "club_resume")) {
    $utility->handleError(404, "Resume not found!");
    die();
}

// اعتبارسنجی و پاک‌سازی ورودی‌ها
$fields = [
    'user_logoPicture' => 'string',
    'user_samplePhoto1' => 'string',
    'user_samplePhoto2' => 'string',
    'user_samplePhoto3' => 'string',
    'user_name' => 'string',
    'user_sportFields' => 'string',
    'user_similarWords' => 'string',
    'user_province' => 'string',
    'user_city' => 'string',
    'user_address' => 'string',
    'location_latitude' => 'float',
    'location_longitude' => 'float',
    'user_phone' => 'string',
    'user_hidePhone' => 'string',
    'user_telephone' => 'string',
    'user_email' => 'email',
    'user_startTime' => 'string',
    'user_endTime' => 'string',
    'user_registrationNumber' => 'string',
    'user_website' => 'string',
    'user_instagram' => 'string',
    'user_telegram' => 'string',
    'user_rubika' => 'string',
    'user_eitaa' => 'string',
    'user_description' => 'string',
    'date_create' => 'string',
];

$input_data = [];
foreach ($fields as $key => $type) {
    $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
}

$image_path = "../../../pictuers/";


$input_data['user_logoPicture'] = $utility->saveBase64Image($input_data['user_logoPicture'] ?? null, $image_path);
$input_data['user_samplePhoto1'] = $utility->saveBase64Image($input_data['user_samplePhoto1'] ?? null, $image_path);
$input_data['user_samplePhoto2'] = $utility->saveBase64Image($input_data['user_samplePhoto2'] ?? null, $image_path);
$input_data['user_samplePhoto3'] = $utility->saveBase64Image($input_data['user_samplePhoto3'] ?? null, $image_path);

// آماده‌سازی و اجرای دستور SQL
$sql = "UPDATE club_resume SET
    logo_picture = :user_logoPicture, environment_photo_1 = :user_samplePhoto1, environment_photo_2 = :user_samplePhoto2, environment_photo_3 = :user_samplePhoto3,
    name = :user_name, sport_fields = :user_sportFields, similar_words = :user_similarWords,
    province = :user_province, city = :user_city, address = :user_address, latitude = :location_latitude, longitude = :location_longitude,
    hide_phone = :user_hidePhone, telephone = :user_telephone, email = :user_email,
    start_time = :user_startTime, end_time = :user_endTime,
    registration_number = :user_registrationNumber, website = :user_website, instagram = :user_instagram, telegram = :user_telegram, rubika = :user_rubika, eitaa = :user_eitaa,
    description = :user_description, date_create = :date_create
WHERE phone = :user_phone";

$stmt = $conn->prepare($sql);

foreach ($fields as $key => $type) {
    $stmt->bindValue(":$key", $input_data[$key], PDO::PARAM_STR);
}

if ($stmt->execute()) {
   

    $token = [
        "iss" => ISSUER,
        "aud" => AUDIENCE,
        "iat" => ISSUED_AT,
        "nbf" => NOT_BEFORE,
        "exp" => EXPIRATION_TIME,
        "data" =>  $token_data = [
        'user_phone' => $input_data['user_phone'],
        'user_province' => $input_data['user_province'],
        'user_city' => $input_data['user_city']
    ]
    ];

    $jwt = JWT::encode($token, JWT_KEY);
    http_response_code(200);
    echo json_encode(["message" => "Success", "jwt" => $jwt]);
} else {
    $errorInfo = $stmt->errorInfo();
    $utility->handleError(500, "Unable to update resume. Error: " . $errorInfo[2]);
    die();
}

?>