<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "اتصال به پایگاه داده امکان‌پذیر نیست: " . $e->getMessage());
    die();
}

$resume = new Resume($conn);
$user = new User($conn);
$data = json_decode(file_get_contents("php://input"));

$phone = htmlspecialchars(strip_tags($data->user_phone));

// دریافت و بررسی توکن JWT
$encodedString = $utility->getToken();
$decodedPayload = null;

if ($encodedString) {
    try {
        $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
        $decodedPayload = (array) $decodedToken->data;

        if (!isset($decodedPayload['user_phone'])) {
            $utility->handleError(401, "شماره تلفن در توکن یافت نشد.");
        }

        if ($decodedPayload['user_phone'] !== $data->user_phone) {
            $utility->handleError(403, "شماره تلفن توکن با شماره تلفن ارائه شده مطابقت ندارد.");
        }

    } catch (\Firebase\JWT\ExpiredException $e) {
        $utility->handleError(401, "توکن JWT منقضی شده است.");
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "امضای JWT نامعتبر است.");
    } catch (Exception $e) {
        $utility->handleError(401, "توکن JWT نامعتبر است.");
    }
} else {
    $utility->handleError(400, "هیچ توکن JWT در هدر Authorization یافت نشد.");
}

// اعتبارسنجی شماره تلفن
$resume->phone = $utility->validateInput($data->user_phone, 'string');

if (strlen($phone) > 15) {
    $utility->handleError(400, "شماره تلفن نمی‌تواند بیشتر از ۱۵ کاراکتر باشد.");
    die();
}

if (!$resume->phoneExists1($phone, "users")) {
    $utility->handleError(404, "کاربری با این شماره تلفن یافت نشد!");
    die();
}

// اعتبارسنجی و پاک‌سازی داده‌های ورودی
$fields = [
    'user_profilePicture' => 'string',
    'first_name' => 'string',
    'last_name' => 'string',
    'user_province' => 'string',
    'user_city' => 'string',
    'user_address' => 'string',
    'location_latitude' => 'float',
    'location_longitude' => 'float',
    'user_phone' => 'string',
    'user_hidePhone' => 'string',
    'user_email' => 'email',
    'user_gender' => 'string',
    'user_maritalState' => 'string',
    'user_dateOfBirth' => 'string',
    'user_educationDegree' => 'string',
    'user_workExperience' => 'string',
    'user_skills' => 'string',
    'user_similarWords' => 'string',
    'user_samplePhoto1' => 'string',
    'user_samplePhoto2' => 'string',
    'user_samplePhoto3' => 'string',
    'user_sampleDescription' => 'string',
    'user_requestForMany' => 'string',
    'user_status' => 'string',
    'user_startTime' => 'string',
    'user_endTime' => 'string',
    'user_rubika' => 'string',
    'user_telegram' => 'string',
    'user_instagram' => 'string',
    'user_eitaa' => 'string',
    'user_description' => 'string',
    'date_create' => 'string'
];

$input_data = [];
foreach ($fields as $key => $type) {
    $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
}

// ذخیره تصاویر در سرور
$image_path = "../../../pictuers/";
$profilePictureName = $utility->saveBase64Image($input_data['user_profilePicture'], $image_path);
$photo1Name = $utility->saveBase64Image($input_data['user_samplePhoto1'] ?? null, $image_path);
$photo2Name = $utility->saveBase64Image($input_data['user_samplePhoto2'] ?? null, $image_path);
$photo3Name = $utility->saveBase64Image($input_data['user_samplePhoto3'] ?? null, $image_path);

// آماده‌سازی دستور SQL برای به‌روزرسانی
$sql = "UPDATE person_resume SET 
profile_picture = :pp, first_name = :fn, last_name = :ln, province = :pr, city = :ci, hide_phone = :hp, 
email = :em, gender = :ge, marital_status = :ms, birth_date = :da, education_degree = :ed, 
work_experience = :we, skills = :sk, salaries = :rf, description = :des, address = :add, rubika = :ru, 
telegram = :telg, instagram = :insta, latitude = :lat, longitude = :lon, date_create = :datec, 
similar_words = :sw, achievement_photo_1 = :ap1, achievement_photo_2 = :ap2, achievement_photo_3 = :ap3, 
achievement_description = :ad, status = :st, start_time = :stime, end_time = :etime, eitaa = :ei 
WHERE phone = :ph";

$stmt = $conn->prepare($sql);

$params = [
    ':pp' => $profilePictureName,
    ':fn' => $input_data['first_name'],
    ':ln' => $input_data['last_name'],
    ':pr' => $input_data['user_province'],
    ':ci' => $input_data['user_city'],
    ':ph' => $input_data['user_phone'],
    ':hp' => $input_data['user_hidePhone'],
    ':em' => $input_data['user_email'],
    ':ge' => $input_data['user_gender'],
    ':ms' => $input_data['user_maritalState'],
    ':da' => $input_data['user_dateOfBirth'],
    ':ed' => $input_data['user_educationDegree'],
    ':we' => $input_data['user_workExperience'],
    ':sk' => $input_data['user_skills'],
    ':rf' => $input_data['user_requestForMany'],
    ':des' => $input_data['user_description'],
    ':add' => $input_data['user_address'],
    ':ru' => $input_data['user_rubika'],
    ':telg' => $input_data['user_telegram'],
    ':insta' => $input_data['user_instagram'],
    ':lat' => $input_data['location_latitude'],
    ':lon' => $input_data['location_longitude'],
    ':datec' => $input_data['date_create'],
    ':sw' => $input_data['user_similarWords'],
    ':ap1' => $photo1Name,
    ':ap2' => $photo2Name,
    ':ap3' => $photo3Name,
    ':ad' => $input_data['user_sampleDescription'],
    ':st' => $input_data['user_status'],
    ':stime' => $input_data['user_startTime'],
    ':etime' => $input_data['user_endTime'],
    ':ei' => $input_data['user_eitaa']
];

foreach ($params as $key => &$val) {
    $stmt->bindParam($key, $val, PDO::PARAM_STR);
}

if ($stmt->execute()) {
    // ایجاد JWT جدید بعد از موفقیت در به‌روزرسانی رزومه
    $token_data = [];
    foreach ($fields as $key => $type) {
        $token_data[$key] = $input_data[$key];
    }

    $token = [
        "iss" => ISSUER,
        "aud" => AUDIENCE,
        "iat" => ISSUED_AT,
        "nbf" => NOT_BEFORE,
        "exp" => EXPIRATION_TIME,
        "data" => [
            'user_phone' => $input_data['user_phone'],
            'user_province' => $input_data['user_province'],
            'user_city' => $input_data['user_city']
        ]
    ];

    $jwt = JWT::encode($token, JWT_KEY);
    http_response_code(200);
    echo json_encode(["message" => "رزومه با موفقیت به‌روزرسانی شد", "jwt" => $jwt]);
} else {
    $utility->handleError(500, "به‌روزرسانی رزومه با خطا مواجه شد.");
    die();
}

?>