<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    http_response_code(503); // Service unavailable
    echo json_encode(["message" => "Unable to connect to the database."]);
    exit();
}

$data = json_decode(file_get_contents("php://input"));

if (!isset($data->user_phone) || empty($data->user_phone)) {
    http_response_code(400); // Bad request
    echo json_encode(["message" => "Phone number is required."]);
    exit();
}

$phone = htmlspecialchars(strip_tags($data->user_phone));

try {
    $query_select = "SELECT * FROM users WHERE phone = :phone";
    $stmt = $conn->prepare($query_select);
    $stmt->bindParam(':phone', $phone);
    $stmt->execute();

    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($user) {
        echo json_encode(["user_phone" => $user["phone"]]);
    } else {
        http_response_code(404); // Not found
        echo json_encode(["message" => "User not found."]);
    }
} catch (Exception $e) {
    http_response_code(500); // Internal server error
    echo json_encode(["message" => "An error occurred while fetching user data."]);
}

?>