<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';

// ایجاد نمونه‌ای از کلاس Utility برای مدیریت خطاها
$utility = new Utility();

try {
    // اتصال به پایگاه داده
    $database = new DataBase();
    $conn = $database->getConnection();
} catch(Exception $e) {
    // استفاده از Utility برای ارسال خطای اتصال به پایگاه داده
    $utility->handleError(503, "متأسفانه ارتباط با پایگاه داده برقرار نشد. لطفاً مجدداً تلاش کنید.");
    die();
}

// ایجاد نمونه‌ای از کلاس Resume
$resume = new Resume($conn);

// بررسی دریافت پارامترهای ضروری
if (!isset($_GET['user_keyword']) || empty($_GET['user_keyword'])) {
    // استفاده از Utility برای ارسال خطای ناقص بودن داده‌ها
    $utility->handleError(400, "کلیدواژه جستجو وارد نشده است. لطفاً دوباره تلاش کنید.");
    die();
}

// امن‌سازی ورودی‌ها
$resume->keyword = htmlspecialchars(strip_tags($_GET['user_keyword']));
$searchKeyword = "%{$resume->keyword}%";

// تعریف کوئری جداول
$allTablesQuery = "
    SELECT 'person_resume' as source_table, 
        profile_picture as picture,
        first_name, 
        last_name,
        province,
        city,
        phone,
        skills as expertise_field,
        similar_words
    FROM person_resume
    WHERE (skills LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'student_resume' as source_table, 
        profile_picture as picture,
        first_name, 
        last_name,
        province,
        city,
        phone,
        student_field as expertise_field,
        similar_words
    FROM student_resume
    WHERE (student_field LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'teacher_resume' as source_table, 
        profile_picture as picture,
        first_name, 
        last_name,
        province,
        city,
        phone,
        teacher_field as expertise_field,
        similar_words
    FROM teacher_resume
    WHERE (teacher_field LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'transportation_resume' as source_table, 
        profile_picture as picture,
        first_name, 
        last_name,
        province,
        city,
        phone,
        car_category as expertise_field,
        similar_words
    FROM transportation_resume
    WHERE (car_category LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'club_resume' as source_table, 
        COALESCE(logo_picture, '') as picture, 
        name as first_name,
        '' as last_name,
        province,
        city,
        phone,
        sport_fields as expertise_field,
        similar_words
    FROM club_resume
    WHERE (sport_fields LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'company_resume' as source_table, 
        COALESCE(logo_picture, '') as picture, 
        name as first_name,
        '' as last_name,
        province,
        city,
        phone,
        company_category as expertise_field,
        similar_words
    FROM company_resume
    WHERE (company_category LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'school_resume' as source_table, 
        COALESCE(logo_picture, '') as picture, 
        name as first_name,
        '' as last_name,
        province,
        city,
        phone,
        educational_fields as expertise_field,
        similar_words
    FROM school_resume
    WHERE (educational_fields LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'store_resume' as source_table, 
        COALESCE(logo_picture, '') as picture, 
        name as first_name,
        '' as last_name,
        province,
        city,
        phone,
        store_category as expertise_field,
        similar_words
    FROM store_resume
    WHERE (store_category LIKE :keyword OR similar_words LIKE :keyword)
    UNION ALL
    SELECT 'workshop_resume' as source_table, 
        COALESCE(logo_picture, '') as picture, 
        name as first_name,
        '' as last_name,
        province,
        city,
        phone,
        workshop_category as expertise_field,
        similar_words
    FROM workshop_resume
    WHERE (workshop_category LIKE :keyword OR similar_words LIKE :keyword)
";

try {
    $stmt = $conn->prepare($allTablesQuery);
    // اتصال مقادیر به پارامترهای کوئری
    $stmt->bindParam(':keyword', $searchKeyword);
    
    // اجرای کوئری
    $stmt->execute();
    
    // دریافت نتایج
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // بررسی اینکه آیا نتیجه‌ای موجود است یا خیر
    if (count($results) > 0) {
        // ارسال پاسخ موفقیت‌آمیز
        echo json_encode($results, JSON_UNESCAPED_UNICODE);
    } else {
        // ارسال پیام در صورت عدم وجود نتیجه
        $utility->handleError(404, "هیچ نتیجه‌ای یافت نشد.");
    }
} catch(Exception $e) {
    // ارسال پیام خطا در صورت بروز اشکال در اجرای کوئری
    $utility->handleError(500, "خطایی در اجرای جستجو رخ داد. لطفاً مجدداً تلاش کنید.");
}
