<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';

// ایجاد نمونه‌ای از کلاس Utility برای مدیریت خطاها
$utility = new Utility();

try {
    // اتصال به پایگاه داده
    $database = new DataBase();
    $conn = $database->getConnection();
} catch(Exception $e) {
    // استفاده از Utility برای ارسال خطای اتصال به پایگاه داده
    $utility->handleError(503, "متأسفانه ارتباط با پایگاه داده برقرار نشد. لطفاً مجدداً تلاش کنید.");
    die();
}

// ایجاد نمونه‌ای از کلاس Resume
$resume = new Resume($conn);

// بررسی دریافت پارامترهای ضروری
if (!isset($_GET['user_phone']) || empty($_GET['user_phone'])) {
    // استفاده از Utility برای ارسال خطای ناقص بودن داده‌ها
    $utility->handleError(400, "شماره موبایل وارد نشده است. لطفاً دوباره تلاش کنید.");
    die();
}

// امن‌سازی ورودی‌ها
$resume->phone = htmlspecialchars(strip_tags($_GET['user_phone']));

// تعریف کوئری جداول بر اساس شماره موبایل، بدون similar_words
$allTablesQuery = "
    SELECT 'person_resume' as source_table, 
        phone
    FROM person_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'student_resume' as source_table, 
        phone
    FROM student_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'teacher_resume' as source_table, 
        phone
    FROM teacher_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'transportation_resume' as source_table, 
        phone
    FROM transportation_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'club_resume' as source_table, 
        phone
    FROM club_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'company_resume' as source_table, 
        phone
    FROM company_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'school_resume' as source_table, 
        phone
    FROM school_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'store_resume' as source_table, 
        phone
    FROM store_resume
    WHERE phone = :phone
    UNION ALL
    SELECT 'workshop_resume' as source_table, 
        phone
    FROM workshop_resume
    WHERE phone = :phone
";

try {
    $stmt = $conn->prepare($allTablesQuery);
    // اتصال مقادیر به پارامترهای کوئری
    $stmt->bindParam(':phone', $resume->phone);
    
    // اجرای کوئری
    $stmt->execute();
    
    // دریافت نتایج
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // بررسی اینکه آیا نتیجه‌ای موجود است یا خیر
    if (count($results) > 0) {
        // ارسال نتیجه شامل شماره و نام جدول
        echo json_encode($results);
    } else {
        // ارسال عدد 0 در صورت عدم وجود نتیجه
        echo json_encode(0);
    }
} catch(Exception $e) {
    // ارسال پیام خطا در صورت بروز اشکال در اجرای کوئری
    $utility->handleError(500, "خطایی در اجرای جستجو رخ داد. لطفاً مجدداً تلاش کنید.");
}
