<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';

// ایجاد نمونه‌ای از کلاس Utility برای مدیریت خطاها
$utility = new Utility();

try {
    // اتصال به پایگاه داده
    $database = new DataBase();
    $conn = $database->getConnection();
} catch(Exception $e) {
    // استفاده از Utility برای ارسال خطای اتصال به پایگاه داده
    $utility->handleError(503, "متأسفانه ارتباط با پایگاه داده برقرار نشد. لطفاً مجدداً تلاش کنید.");
    die();
}

// ایجاد نمونه‌ای از کلاس Resume
$resume = new Resume($conn);

// بررسی دریافت پارامترهای ضروری
if (!isset($_GET['user_keyword']) || empty($_GET['user_keyword'])) {
    // استفاده از Utility برای ارسال خطای ناقص بودن داده‌ها
    $utility->handleError(400, "کلیدواژه جستجو وارد نشده است. لطفاً دوباره تلاش کنید.");
    die();
}

// امن‌سازی ورودی‌ها
$resume->keyword = htmlspecialchars(strip_tags($_GET['user_keyword']));
$searchKeyword = "%{$resume->keyword}%";

// فیلترهای province و city را به صورت اختیاری بررسی می‌کنیم
$filterConditions = '';
$filters = [];

// اگر province موجود است به شرط اضافه می‌شود
if (isset($_GET['user_province']) && !empty($_GET['user_province'])) {
    $resume->province = htmlspecialchars(strip_tags($_GET['user_province']));
    $filterConditions .= " AND province = :province";
    $filters[':province'] = $resume->province;
}

// اگر city موجود است به شرط اضافه می‌شود
if (isset($_GET['user_city']) && !empty($_GET['user_city'])) {
    $resume->city = htmlspecialchars(strip_tags($_GET['user_city']));
    $filterConditions .= " AND city = :city";
    $filters[':city'] = $resume->city;
}

// بررسی جداولی که کاربر می‌خواهد فیلتر کند
$tables = isset($_GET['tables']) && !empty($_GET['tables']) ? explode(",", $_GET['tables']) : [];

// بررسی فیلتر وضعیت (status) برای جداول teacher, student, person
if (in_array('teacher_resume', $tables) || in_array('student_resume', $tables) || in_array('person_resume', $tables)) {
    if (isset($_GET['status']) && !empty($_GET['status'])) {
        $statuses = explode(',', $_GET['status']); // جدا کردن کلمات با کاما
        $statusPlaceholders = [];
        foreach ($statuses as $index => $status) {
            $status = htmlspecialchars(strip_tags(trim($status))); // حذف تگ‌های ناامن و فضاهای اضافی
            $placeholder = ":status" . $index; // ایجاد placeholder های متفاوت
            $statusPlaceholders[] = "status = $placeholder";
            $filters[$placeholder] = $status; // مقداردهی متغیرهای placeholder
        }
        // ایجاد شرط فیلتر با استفاده از OR
        $filterConditions .= " AND (" . implode(' OR ', $statusPlaceholders) . ")";
    }
}


// تعریف کوئری جداول به صورت پیش‌فرض
$allTablesQuery = "
   SELECT 'person_resume' as source_table, 
    profile_picture as picture,
    first_name, 
    last_name,
    province,
    city,
    phone,
    skills as expertise_field,
    similar_words
FROM person_resume
WHERE (skills LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'student_resume' as source_table, 
    profile_picture as picture,
    first_name, 
    last_name,
    province,
    city,
    phone,
    student_field as expertise_field,
    similar_words
FROM student_resume
WHERE (student_field LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'teacher_resume' as source_table, 
    profile_picture as picture,
    first_name, 
    last_name,
    province,
    city,
    phone,
    teacher_field as expertise_field,
    similar_words
FROM teacher_resume
WHERE (teacher_field LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'transportation_resume' as source_table, 
    profile_picture as picture,
    first_name, 
    last_name,
    province,
    city,
    phone,
    car_category as expertise_field,
    similar_words
FROM transportation_resume
WHERE (car_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'club_resume' as source_table, 
    COALESCE(logo_picture, '') as picture, 
    name as first_name,
    '' as last_name,
    province,
    city,
    phone,
    sport_fields as expertise_field,
    similar_words
FROM club_resume
WHERE (sport_fields LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'company_resume' as source_table, 
    COALESCE(logo_picture, '') as picture, 
    name as first_name,
    '' as last_name,
    province,
    city,
    phone,
    company_category as expertise_field,
    similar_words
FROM company_resume
WHERE (company_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'school_resume' as source_table, 
    COALESCE(logo_picture, '') as picture, 
    name as first_name,
    '' as last_name,
    province,
    city,
    phone,
    educational_fields as expertise_field,
    similar_words
FROM school_resume
WHERE (educational_fields LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'store_resume' as source_table, 
    COALESCE(logo_picture, '') as picture, 
    name as first_name,
    '' as last_name,
    province,
    city,
    phone,
    store_category as expertise_field,
    similar_words
FROM store_resume
WHERE (store_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
UNION ALL
SELECT 'workshop_resume' as source_table, 
    COALESCE(logo_picture, '') as picture, 
    name as first_name,
    '' as last_name,
    province,
    city,
    phone,
    workshop_category as expertise_field,
    similar_words
FROM workshop_resume
WHERE (workshop_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions
";

// فیلتر کردن جداول در صورتی که کاربر بخواهد
$tableQueries = [];
if (!empty($tables)) {
    if (in_array('person_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'person_resume' as source_table, 
            profile_picture as picture,
            first_name, 
            last_name,
            province,
            city,
            phone,
            skills as expertise_field,
            similar_words
        FROM person_resume
        WHERE (skills LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('student_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'student_resume' as source_table, 
            profile_picture as picture,
            first_name, 
            last_name,
            province,
            city,
            phone,
            student_field as expertise_field,
            similar_words
        FROM student_resume
        WHERE (student_field LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('teacher_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'teacher_resume' as source_table, 
            profile_picture as picture,
            first_name, 
            last_name,
            province,
            city,
            phone,
            teacher_field as expertise_field,
            similar_words
        FROM teacher_resume
        WHERE (teacher_field LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('transportation_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'transportation_resume' as source_table, 
            profile_picture as picture,
            first_name, 
            last_name,
            province,
            city,
            phone,
            car_category as expertise_field,
            similar_words
        FROM transportation_resume
        WHERE (car_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('club_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'club_resume' as source_table, 
            COALESCE(logo_picture, '') as picture, 
            name as first_name,
            '' as last_name,
            province,
            city,
            phone,
            sport_fields as expertise_field,
            similar_words
        FROM club_resume
        WHERE (sport_fields LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('company_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'company_resume' as source_table, 
            COALESCE(logo_picture, '') as picture, 
            name as first_name,
            '' as last_name,
            province,
            city,
            phone,
            company_category as expertise_field,
            similar_words
        FROM company_resume
        WHERE (company_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('school_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'school_resume' as source_table, 
            COALESCE(logo_picture, '') as picture, 
            name as first_name,
            '' as last_name,
            province,
            city,
            phone,
            educational_fields as expertise_field,
            similar_words
        FROM school_resume
        WHERE (educational_fields LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('store_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'store_resume' as source_table, 
            COALESCE(logo_picture, '') as picture, 
            name as first_name,
            '' as last_name,
            province,
            city,
            phone,
            store_category as expertise_field,
            similar_words
        FROM store_resume
        WHERE (store_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
    if (in_array('workshop_resume', $tables)) {
        $tableQueries[] = "
        SELECT 'workshop_resume' as source_table, 
            COALESCE(logo_picture, '') as picture, 
            name as first_name,
            '' as last_name,
            province,
            city,
            phone,
            workshop_category as expertise_field,
            similar_words
        FROM workshop_resume
        WHERE (workshop_category LIKE :keyword OR similar_words LIKE :keyword) $filterConditions";
    }
}

// کوئری نهایی که باید اجرا شود
$finalQuery = !empty($tableQueries) ? implode(" UNION ALL ", $tableQueries) : $allTablesQuery;

try {
    $stmt = $conn->prepare($finalQuery);
    // اتصال مقادیر به پارامترهای کوئری
    foreach ($filters as $key => &$value) {
        $stmt->bindParam($key, $value);
    }
    $stmt->bindParam(':keyword', $searchKeyword);
    
    // اجرای کوئری
    $stmt->execute();
    
    // دریافت نتایج
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // بررسی اینکه آیا نتیجه‌ای موجود است یا خیر
    if (count($results) > 0) {
        // ارسال پاسخ موفقیت‌آمیز
        echo json_encode( $results, JSON_UNESCAPED_UNICODE);
    } else {
        // ارسال پیام در صورت عدم وجود نتیجه
        $utility->handleError(404, "هیچ نتیجه‌ای یافت نشد.");
    }
} catch(Exception $e) {
    // ارسال پیام خطا در صورت بروز اشکال در اجرای کوئری
    $utility->handleError(500, "خطایی در اجرای جستجو رخ داد. لطفاً مجدداً تلاش کنید.");
}
