<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php'; // بارگذاری تنظیمات JWT
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

$utility = new Utility();


function respond($status, $message) {
    http_response_code($status);
    echo json_encode(["message" => $message]);
    exit();
}



try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    respond(503, "Unable to connect to the database.");
}

$user = new User($conn);
$data = json_decode(file_get_contents("php://input"), true);

$user->phone = htmlspecialchars(strip_tags($data['user_phone']));

if($user->phone == "" || $user->phone == null){
    respond(400, "Phone not found");
} else {
    // Check if phone number already exists
    if ($user->phoneExists($user->phone)) {
        respond(400, "Sign up failed, phone already exists.");
    }

    if ($user->createUser()) {
        $token = [
            "iss" => ISSUER,
            "aud" => AUDIENCE,
            "iat" => ISSUED_AT,
            "nbf" => NOT_BEFORE,
            "exp" => EXPIRATION_TIME,
            "data" => [
                "user_phone" => $user->phone
            ]
        ];

        try {
            $jwt = JWT::encode($token, JWT_KEY);
            http_response_code(201);
            echo json_encode(["jwt" => $jwt]);
            exit();
        } catch (Exception $e) {
            respond(500, "Failed to encode JWT: " . $e->getMessage());
        }
    } else {
        respond(503, "Unable to create user.");
    }
}
?>