<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "اتصال به پایگاه داده امکان‌پذیر نیست.");
    die();
}

$resume = new Resume($conn);
$data = json_decode(file_get_contents("php://input"));

if (!isset($data->user_phone) || empty(trim($data->user_phone))) {
    $utility->handleError(400, "شماره تلفن الزامی است.");
    die();
}

$phone = $utility->validateInput($data->user_phone, 'string', 15);

$encodedString = $utility->getToken();
if (!$encodedString) {
    $utility->handleError(401, "توکن احراز هویت یافت نشد.");
    die();
}

try {
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $payload = (array)$decodedToken->data;
    
    $userRole = $payload['access_level'] ?? 'user';
    $isAdmin = in_array($userRole, ['manager', 1, 2, 3]);
    
    if (!$isAdmin && (!isset($payload['user_phone']) || $payload['user_phone'] !== $phone)) {
        $utility->handleError(403, "دسترسی غیرمجاز به این شماره تلفن.");
        die();
    }
} catch (Exception $e) {
    $utility->handleError(401, "خطای احراز هویت: " . $e->getMessage());
    die();
}

if ($resume->phoneExists1($phone, "student_resume")) {
    $utility->handleError(409, "رزومه قبلاً ثبت شده است.");
    die();
}

$fields = [
    'user_profilePicture' => 'string',
    'first_name' => 'string',
    'last_name' => 'string',
    'user_province' => 'string',
    'user_city' => 'string',
    'user_address' => 'string',
    'location_latitude' => 'float',
    'location_longitude' => 'float',
    'user_phone' => 'string',
    'user_hidePhone' => 'string',
    'user_email' => 'email',
    'user_gender' => 'string',
    'user_maritalState' => 'string',
    'user_dateOfBirth' => 'string',
    'user_educationDegree' => 'string',
    'user_workExperience' => 'string',
    'user_studentField' => 'string',
    'user_similarWords' => 'string',
    'user_samplePhoto1' => 'string',
    'user_samplePhoto2' => 'string',
    'user_samplePhoto3' => 'string',
    'user_sampleDescription' => 'string',
    'user_requestForMany' => 'string',
    'user_status' => 'string',
    'user_startTime' => 'string',
    'user_endTime' => 'string',
    'user_rubika' => 'string',
    'user_telegram' => 'string',
    'user_instagram' => 'string',
    'user_eitaa' => 'string',
    'user_description' => 'string',
    'date_create' => 'string',
    'user_university' => 'string',
    'user_universitySemester' => 'string',
    'user_educationDegreeLink' => 'string',
    'user_dissertationLink' => 'string',
    'user_resumeLink' => 'string',
    'user_continuous' => 'string',
    'user_aboveDiplomaField' => 'string',
    'user_aboveDiplomaUniversity' => 'string',
    'user_bachelorField' => 'string',
    'user_bachelorUniversity' => 'string',
    'user_masterField' => 'string',
    'user_masterUniversity' => 'string',
    'use_referral_code' => 'string'
];

$input_data = [];
foreach ($fields as $key => $type) {
    $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
}

$image_path = "../../../pictuers/";
$profilePictureName = $utility->saveBase64Image($input_data['user_profilePicture'], $image_path);
$photo1Name = $utility->saveBase64Image($input_data['user_samplePhoto1'], $image_path);
$photo2Name = $utility->saveBase64Image($input_data['user_samplePhoto2'], $image_path);
$photo3Name = $utility->saveBase64Image($input_data['user_samplePhoto3'], $image_path);

try {
    $conn->beginTransaction();

    if (!$resume->phoneExists1($phone, "users")) {
        $stmt_user = $conn->prepare("INSERT INTO users (phone, province, city) VALUES (:ph, :pr, :ci)");
        $stmt_user->execute([
            ':ph' => $phone,
            ':pr' => $input_data['user_province'],
            ':ci' => $input_data['user_city']
        ]);
    }

    $sql = "INSERT INTO student_resume (
        profile_picture, first_name, last_name, province, city, phone, hide_phone, email, gender, 
        marital_state, birth_date, education_degree, work_experience, student_field, description, 
        address, rubika, telegram, instagram, latitude, longitude, date_create, similar_words, 
        achievement_photo_1, achievement_photo_2, achievement_photo_3, achievement_description, 
        status, start_time, end_time, eitaa, university, semester, education_degree_link, 
        dissertation_link, resume_link, continuous, above_diploma_field, above_diploma_university, 
        bachelor_field, bachelor_university, master_field, master_university, use_referral_code
    ) VALUES (
        :pi, :fn, :ln, :pr, :ci, :ph, :hp, :em, :ge, :ms, :da, :ed, :we, :sf, :des, :add, :ru, 
        :telg, :insta, :lat, :lon, :datec, :sw, :ap1, :ap2, :ap3, :ad, :st, :stime, :etime, :ei, 
        :us, :sems, :edl, :dl, :rl, :contin, :adf, :adu, :bf, :bu, :mf, :mu, :urc
    )";

    $stmt = $conn->prepare($sql);

    $params = [
        ':pi' => $profilePictureName,
        ':fn' => $input_data['first_name'],
        ':ln' => $input_data['last_name'],
        ':pr' => $input_data['user_province'],
        ':ci' => $input_data['user_city'],
        ':ph' => $phone,
        ':hp' => $input_data['user_hidePhone'],
        ':em' => $input_data['user_email'],
        ':ge' => $input_data['user_gender'],
        ':ms' => $input_data['user_maritalState'],
        ':da' => $input_data['user_dateOfBirth'],
        ':ed' => $input_data['user_educationDegree'],
        ':we' => $input_data['user_workExperience'],
        ':sf' => $input_data['user_studentField'],
        ':des' => $input_data['user_description'],
        ':add' => $input_data['user_address'],
        ':ru' => $input_data['user_rubika'],
        ':telg' => $input_data['user_telegram'],
        ':insta' => $input_data['user_instagram'],
        ':lat' => $input_data['location_latitude'],
        ':lon' => $input_data['location_longitude'],
        ':datec' => $input_data['date_create'],
        ':sw' => $input_data['user_similarWords'],
        ':ap1' => $photo1Name,
        ':ap2' => $photo2Name,
        ':ap3' => $photo3Name,
        ':ad' => $input_data['user_sampleDescription'],
        ':st' => $input_data['user_status'],
        ':stime' => $input_data['user_startTime'],
        ':etime' => $input_data['user_endTime'],
        ':ei' => $input_data['user_eitaa'],
        ':us' => $input_data['user_university'],
        ':sems' => $input_data['user_universitySemester'],
        ':edl' => $input_data['user_educationDegreeLink'],
        ':dl' => $input_data['user_dissertationLink'],
        ':rl' => $input_data['user_resumeLink'],
        ':contin' => $input_data['user_continuous'],
        ':adf' => $input_data['user_aboveDiplomaField'],
        ':adu' => $input_data['user_aboveDiplomaUniversity'],
        ':bf' => $input_data['user_bachelorField'],
        ':bu' => $input_data['user_bachelorUniversity'],
        ':mf' => $input_data['user_masterField'],
        ':mu' => $input_data['user_masterUniversity'],
        ':urc' => $input_data['use_referral_code'] ?? null
    ];

    $stmt->execute($params);

    $conn->commit();

    $token = [
        "iss" => ISSUER,
        "aud" => AUDIENCE,
        "iat" => time(),
        "exp" => time() + EXPIRATION_TIME,
        "data" => [
            'user_phone' => $phone,
            'user_province' => $input_data['user_province'],
            'user_city' => $input_data['user_city'],
            'access_level' => $userRole
        ]
    ];
    $jwt = JWT::encode($token, JWT_KEY);
    
    echo json_encode([
        "status" => "success",
        "message" => "رزومه با موفقیت ایجاد شد.",
        "jwt" => $jwt
    ], JSON_UNESCAPED_UNICODE);

} catch (PDOException $e) {
    $conn->rollBack();
    $utility->handleError(500, "خطای پایگاه داده: " . $e->getMessage());
} catch (Exception $e) {
    $conn->rollBack();
    $utility->handleError(500, "خطای سیستمی: " . $e->getMessage());
}