<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "اتصال به پایگاه داده امکان‌پذیر نیست: " . $e->getMessage());
    die();
}

$resume = new Resume($conn);
$user = new User($conn);
$data = json_decode(file_get_contents("php://input"));

$phone = htmlspecialchars(strip_tags($data->user_phone));

// دریافت و بررسی توکن JWT
$encodedString = $utility->getToken();
$decodedPayload = null;

if ($encodedString) {
    try {
        $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
        $decodedPayload = (array) $decodedToken->data;

        if (!isset($decodedPayload['user_phone'])) {
            $utility->handleError(401, "شماره تلفن در توکن یافت نشد.");
        }

        if ($decodedPayload['user_phone'] !== $data->user_phone) {
            $utility->handleError(403, "شماره تلفن در توکن با شماره تلفن ارائه شده مطابقت ندارد.");
        }

    } catch (\Firebase\JWT\ExpiredException $e) {
        $utility->handleError(401, "توکن JWT منقضی شده است.");
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "امضای JWT نامعتبر است.");
    } catch (Exception $e) {
        $utility->handleError(401, "توکن JWT نامعتبر است.");
    }
} else {
    $utility->handleError(400, "هیچ توکن JWT در هدر Authorization یافت نشد.");
}

$resume->phone = $utility->validateInput($data->user_phone, 'string');

if (strlen($phone) > 15) {
    $utility->handleError(400, "طول شماره تلفن نمی‌تواند بیشتر از ۱۵ کاراکتر باشد.");
    die();
}

// بررسی وجود کاربر
if (!$resume->phoneExists1($phone, "users")) {
    $utility->handleError(404, "دانشجویی با این شماره تلفن یافت نشد!");
    die();
}




// اعتبارسنجی و پاک‌سازی ورودی‌ها
$fields = [
    'user_profilePicture' => 'string',
    'first_name' => 'string',
    'last_name' => 'string',
    'user_province' => 'string',
    'user_city' => 'string',
    'user_address' => 'string',
    'location_latitude' => 'float',
    'location_longitude' => 'float',
    'user_phone' => 'string',
    'user_hidePhone' => 'string',
    'user_email' => 'email',
    'user_gender' => 'string',
    'user_maritalState' => 'string',
    'user_dateOfBirth' => 'string',
    'user_educationDegree' => 'string',
    'user_workExperience' => 'string',
    'user_studentField' => 'string',
    'user_similarWords' => 'string',
    'user_samplePhoto1' => 'string',
    'user_samplePhoto2' => 'string',
    'user_samplePhoto3' => 'string',
    'user_sampleDescription' => 'string',
    'user_requestForMany' => 'string',
    'user_status' => 'string',
    'user_startTime' => 'string',
    'user_endTime' => 'string',
    'user_rubika' => 'string',
    'user_telegram' => 'string',
    'user_instagram' => 'string',
    'user_eitaa' => 'string',
    'user_description' => 'string',
    'date_create' => 'string',
    'user_university' => 'string',
    'user_universitySemester' => 'string',
    'user_educationDegreeLink' => 'string',
    'user_dissertationLink' => 'string',
    'user_resumeLink' => 'string',
    'user_continuous' => 'string',
    'user_aboveDiplomaField' => 'string',
    'user_aboveDiplomaUniversity' => 'string',
    'user_bachelorField' => 'string',
    'user_bachelorUniversity' => 'string',
    'user_masterField' => 'string',
    'user_masterUniversity' => 'string'
];

$input_data = [];
foreach ($fields as $key => $type) {
    $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
}

$image_path = "../../../pictuers/";
$profilePictureName = $utility->saveBase64Image($input_data['user_profilePicture'] ?? null, $image_path);
$photo1Name = $utility->saveBase64Image($input_data['user_samplePhoto1'] ?? null, $image_path);
$photo2Name = $utility->saveBase64Image($input_data['user_samplePhoto2'] ?? null, $image_path);
$photo3Name = $utility->saveBase64Image($input_data['user_samplePhoto3'] ?? null, $image_path);

// آماده‌سازی دستور SQL برای بروزرسانی
$sql = "UPDATE student_resume SET 
    profile_picture = :pi,
    first_name = :fn,
    last_name = :ln,
    province = :pr,
    city = :ci,
    hide_phone = :hp,
    email = :em,
    gender = :ge,
    marital_state = :ms,
    birth_date = :da,
    education_degree = :ed,
    work_experience = :we,
    student_field = :sf,
    description = :des,
    address = :add,
    rubika = :ru,
    telegram = :telg,
    instagram = :insta,
    latitude = :lat,
    longitude = :lon,
    date_create = :datec,
    similar_words = :sw,
    achievement_photo_1 = :ap1,
    achievement_photo_2 = :ap2,
    achievement_photo_3 = :ap3,
    achievement_description = :ad,
    status = :st,
    start_time = :stime,
    end_time = :etime,
    eitaa = :ei,
    university = :us,
    semester = :sems,
    education_degree_link = :edl,
    dissertation_link = :dl,
    resume_link = :rl,
    continuous = :contin,
    above_diploma_field = :adf,
    above_diploma_university = :adu,
    bachelor_field = :bf,
    bachelor_university = :bu,
    master_field = :mf,
    master_university = :mu
WHERE phone = :ph";

$stmt = $conn->prepare($sql);

// اتصال پارامترها
$params = [
    ':pi' => $profilePictureName,
    ':fn' => $input_data['first_name'],
    ':ln' => $input_data['last_name'],
    ':pr' => $input_data['user_province'],
    ':ci' => $input_data['user_city'],
    ':add' => $input_data['user_address'],
    ':lat' => $input_data['location_latitude'],
    ':lon' => $input_data['location_longitude'],
    ':ph' => $input_data['user_phone'],
    ':hp' => $input_data['user_hidePhone'],
    ':em' => $input_data['user_email'],
    ':ge' => $input_data['user_gender'],
    ':ms' => $input_data['user_maritalState'],
    ':da' => $input_data['user_dateOfBirth'],
    ':ed' => $input_data['user_educationDegree'],
    ':we' => $input_data['user_workExperience'],
    ':sf' => $input_data['user_studentField'],
    ':sw' => $input_data['user_similarWords'],
    ':ap1' => $photo1Name,
    ':ap2' => $photo2Name,
    ':ap3' => $photo3Name,
    ':ad' => $input_data['user_sampleDescription'],
    ':des' => $input_data['user_description'],
    ':ru' => $input_data['user_rubika'],
    ':telg' => $input_data['user_telegram'],
    ':insta' => $input_data['user_instagram'],
    ':datec' => $input_data['date_create'],
    ':st' => $input_data['user_status'],
    ':stime' => $input_data['user_startTime'],
    ':etime' => $input_data['user_endTime'],
    ':ei' => $input_data['user_eitaa'],
    ':us' => $input_data['user_university'],
    ':sems' => $input_data['user_universitySemester'],
    ':edl' => $input_data['user_educationDegreeLink'],
    ':dl' => $input_data['user_dissertationLink'],
    ':rl' => $input_data['user_resumeLink'],
    ':contin' => $input_data['user_continuous'],
    ':adf' => $input_data['user_aboveDiplomaField'],
    ':adu' => $input_data['user_aboveDiplomaUniversity'],
    ':bf' => $input_data['user_bachelorField'],
    ':bu' => $input_data['user_bachelorUniversity'],
    ':mf' => $input_data['user_masterField'],
    ':mu' => $input_data['user_masterUniversity']
];

foreach ($params as $key => &$val) {
    $stmt->bindParam($key, $val, PDO::PARAM_STR);
}

if ($stmt->execute()) {
    // Generate a new JWT after successful resume update
    $token_data = [
        'user_phone' => $input_data['user_phone'],
        'user_province' => $input_data['user_province'],
        'user_city' => $input_data['user_city']
    ];

    $token = [
        "iss" => ISSUER,
        "aud" => AUDIENCE,
        "iat" => ISSUED_AT,
        "nbf" => NOT_BEFORE,
        "exp" => EXPIRATION_TIME,
        "data" => $token_data
    ];

    $jwt = JWT::encode($token, JWT_KEY);
    http_response_code(200);
    echo json_encode(["message" => "به‌روزرسانی موفقیت‌آمیز", "jwt" => $jwt], JSON_UNESCAPED_UNICODE);
} else {
    $utility->handleError(500, "به‌روزرسانی رزومه امکان‌پذیر نیست.");
    die();
}
?>
