<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "Unable to connect to the database: " . $e->getMessage());
}

$resume = new Resume($conn);
$data = json_decode(file_get_contents("php://input"));

// دریافت و بررسی توکن JWT
$encodedString = $utility->getToken();
$decodedPayload = null;

if ($encodedString) {
    try {
        $decodedToken = JWT::decode($encodedString, JWT_KEY, array('HS256'));
        $decodedPayload = (array) $decodedToken->data;
        if (!isset($decodedPayload['user_phone'])) {
            $utility->handleError(401, "Phone number not found in the token.");
        }
        if ($decodedPayload['user_phone'] !== $data->user_phone) {
            $utility->handleError(403, "The phone number in the token does not match the provided phone number.");
        }
    } catch (\Firebase\JWT\ExpiredException $e) {
        $utility->handleError(401, "JWT token has expired.");
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "JWT signature is invalid.");
    } catch (Exception $e) {
        $utility->handleError(401, "Invalid JWT token.");
    }
} else {
    $utility->handleError(400, "No JWT token found in the Authorization header.");
}

$phone = $utility->validateInput($data->user_phone, 'string');

// بررسی طول شماره تلفن
if (strlen($phone) > 15) {
    $utility->handleError(400, "Phone number cannot be longer than 15 characters.");
}

// بررسی وجود رزومه
if (!$resume->phoneExists1($phone, "teacher_resume")) {
    $utility->handleError(404, "Resume not found!");
}

// اعتبارسنجی ورودی‌ها
$fields = [
    'user_profilePicture' => 'string',
    'first_name' => 'string',
    'last_name' => 'string',
    'user_province' => 'string',
    'user_city' => 'string',
    'user_address' => 'string',
    'location_latitude' => 'float',
    'location_longitude' => 'float',
    'user_phone' => 'string',
    'user_hidePhone' => 'string',
    'user_email' => 'email',
    'user_gender' => 'string',
    'user_maritalState' => 'string',
    'user_dateOfBirth' => 'string',
    'user_educationDegree' => 'string',
    'user_workExperience' => 'string',
    'user_teacherField' => 'string',
    'user_similarWords' => 'string',
    'user_samplePhoto1' => 'string',
    'user_samplePhoto2' => 'string',
    'user_samplePhoto3' => 'string',
    'user_sampleDescription' => 'string',
    'user_requestForMany' => 'string',
    'user_status' => 'string',
    'user_startTime' => 'string',
    'user_endTime' => 'string',
    'user_rubika' => 'string',
    'user_telegram' => 'string',
    'user_instagram' => 'string',
    'user_eitaa' => 'string',
    'user_description' => 'string',
    'date_create' => 'string'
];

$input_data = [];
foreach ($fields as $key => $type) {
    $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
}

// ذخیره تصاویر
function save_base64_image($base64_image, $path) {
    if ($base64_image) {
        $image_name = uniqid() . '.jpg';
        file_put_contents($path . $image_name, base64_decode($base64_image));
        return $image_name;
    }
    return ""; // اگر تصویری موجود نباشد، مقدار null بازگردانده می‌شود
}

$image_path = "../../../pictuers/";
$profilePictureName = save_base64_image($input_data['user_profilePicture'], $image_path);
$photo1Name = save_base64_image($input_data['user_samplePhoto1'], $image_path);
$photo2Name = save_base64_image($input_data['user_samplePhoto2'], $image_path);
$photo3Name = save_base64_image($input_data['user_samplePhoto3'], $image_path);

// دستور SQL برای بروزرسانی اطلاعات
$sql = "UPDATE teacher_resume SET
    profile_picture = :pi,
    first_name = :fn,
    last_name = :ln,
    province = :pr,
    city = :ci,
    email = :em,
    gender = :ge,
    marital_state = :ms,
    birth_date = :da,
    education_degree = :ed,
    work_experience = :we,
    teacher_field = :tf,
    salaries = :rf,
    description = :des,
    address = :add,
    rubika = :ru,
    telegram = :telg,
    instagram = :insta,
    latitude = :lat,
    longitude = :lon,
    date_create = :datec,
    similar_words = :sw,
    achievement_photo_1 = :ap1,
    achievement_photo_2 = :ap2,
    achievement_photo_3 = :ap3,
    achievement_description = :ad,
    status = :st,
    start_time = :stime,
    end_time = :etime,
    eitaa = :ei,
    hide_phone = :hp
WHERE phone = :ph";

$stmt = $conn->prepare($sql);

// بایند کردن مقادیر
$params = [
    ':pi' => $profilePictureName,
    ':fn' => $input_data['first_name'],
    ':ln' => $input_data['last_name'],
    ':pr' => $input_data['user_province'],
    ':ci' => $input_data['user_city'],
    ':ph' => $input_data['user_phone'],
    ':hp' => $input_data['user_hidePhone'],
    ':em' => $input_data['user_email'],
    ':ge' => $input_data['user_gender'],
    ':ms' => $input_data['user_maritalState'],
    ':da' => $input_data['user_dateOfBirth'],
    ':ed' => $input_data['user_educationDegree'],
    ':we' => $input_data['user_workExperience'],
    ':tf' => $input_data['user_teacherField'],
    ':rf' => $input_data['user_requestForMany'],
    ':des' => $input_data['user_description'],
    ':add' => $input_data['user_address'],
    ':ru' => $input_data['user_rubika'],
    ':telg' => $input_data['user_telegram'],
    ':insta' => $input_data['user_instagram'],
    ':lat' => $input_data['location_latitude'],
    ':lon' => $input_data['location_longitude'],
    ':datec' => $input_data['date_create'],
    ':sw' => $input_data['user_similarWords'],
    ':ap1' => $photo1Name,
    ':ap2' => $photo2Name,
    ':ap3' => $photo3Name,
    ':ad' => $input_data['user_sampleDescription'],
    ':st' => $input_data['user_status'],
    ':stime' => $input_data['user_startTime'],
    ':etime' => $input_data['user_endTime'],
    ':ei' => $input_data['user_eitaa']
];

foreach ($params as $key => &$val) {
    $stmt->bindParam($key, $val, PDO::PARAM_STR);
}

// Execute the statement
if ($stmt->execute()) {
    // تولید JWT جدید پس از موفقیت‌آمیز بودن بروزرسانی رزومه
    $token_data = [];
    foreach ($fields as $key => $type) {
        $token_data[$key] = $input_data[$key];
    }
    $token_data['achievement_photo_1'] = $photo1Name;
    $token_data['achievement_photo_2'] = $photo2Name;
    $token_data['achievement_photo_3'] = $photo3Name;

   $token = [
        "iss" => ISSUER,
        "aud" => AUDIENCE,
        "iat" => ISSUED_AT,
        "nbf" => NOT_BEFORE,
        "exp" => EXPIRATION_TIME,
        "data" =>  $token_data = [
        'user_phone' => $input_data['user_phone'],
        'user_province' => $input_data['user_province'],
        'user_city' => $input_data['user_city']
    ]
    ];

    $jwt = JWT::encode($token, JWT_KEY);
    http_response_code(200);
    echo json_encode(["message" => "Success", "jwt" => $jwt]);
} else {
    $errorInfo = $stmt->errorInfo();
    $utility->handleError(500, "Unable to update resume. Error: " . $errorInfo[2]);
    die();
}

?>