<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

// شامل کردن فایل‌های مورد نیاز
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;
$utility = new Utility();

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();
if (!$encodedString) {
    $utility->handleError(400, "توکن JWT در هدر Authorization یافت نشد.");
    exit();
}

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));
if (empty($data->user_phone)) {
    $utility->handleError(400, "شماره تلفن کاربر الزامی است.");
    exit();
}
$phone = $utility->validateInput($data->user_phone, 'string');
if (strlen($phone) > 15) {
    $utility->handleError(400, "شماره تلفن نمی‌تواند بیشتر از ۱۵ کاراکتر باشد.");
    exit();
}

try {
    // بررسی اعتبار توکن
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $decodedPayload = (array) $decodedToken->data;
    
    // بررسی نقش کاربر (user یا admin/manager)
    $userRole = $decodedPayload['access_level'] ?? 'user';
    $isAdminOrManager = in_array($userRole, ['manager', 'admin', '1', '2', '3']);
    
    // اگر کاربر admin/manager نباشد، بررسی می‌کنیم که شماره تلفن در توکن با شماره تلفن ارائه شده مطابقت دارد
    if (!$isAdminOrManager) {
        if (!isset($decodedPayload['user_phone'])) {
            $utility->handleError(401, "شماره تلفن در توکن یافت نشد.");
            exit();
        }
        if ($decodedPayload['user_phone'] !== $data->user_phone) {
            $utility->handleError(403, "شماره تلفن در توکن با شماره تلفن ارائه شده مطابقت ندارد.");
            exit();
        }
    }

    // اتصال به دیتابیس
    $database = new Database();
    $conn = $database->getConnection();

    // بررسی وجود شماره تلفن در جدول users
    $user = new User($conn);
    $resume = new Resume($conn);

    if ($resume->phoneExists1($phone, "transportation_resume")) {
        $utility->handleError(409, "رزومه از قبل ثبت شده است.");
        die();
    }

    // اعتبارسنجی و پاک‌سازی ورودی‌ها
    $fields = [
        'user_profilePicture' => 'string',
        'first_name' => 'string',
        'last_name' => 'string',
        'user_province' => 'string',
        'user_city' => 'string',
        'user_address' => 'string',
        'location_latitude' => 'float',
        'location_longitude' => 'float',
        'user_phone' => 'string',
        'user_hidePhone' => 'string',
        'user_email' => 'email',
        'user_gender' => 'string',
        'user_maritalState' => 'string',
        'user_dateOfBirth' => 'string',
        'user_carCategory' => 'string',
        'user_similarWords' => 'string',
        'user_carName' => 'string',
        'user_smartNumber' => 'string',
        'user_startTime' => 'string',
        'user_endTime' => 'string',
        'user_rubika' => 'string',
        'user_telegram' => 'string',
        'user_instagram' => 'string',
        'user_eitaa' => 'string',
        'user_description' => 'string',
        'use_referral_code' => 'string',
        'date_create' => 'string'
    ];

    $input_data = [];
    foreach ($fields as $key => $type) {
        $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
    }

    // ذخیره تصاویر
    $image_path = "../../../pictuers/";
    $profilePictureName = $utility->saveBase64Image($input_data['user_profilePicture'] ?? null, $image_path);

    // آماده‌سازی دستور SQL
    $sql = "INSERT INTO transportation_resume
            (profile_picture, first_name, last_name, province, city, phone, hide_phone, email, gender, marital_state, birth_date, car_category, car_name, smart_number, description, address, rubika, telegram, instagram, latitude, longitude, date_create, similar_words, start_time, end_time, eitaa, use_referral_code)
            VALUES
            (:pi, :fn, :ln, :pr, :ci, :ph, :hp, :em, :ge, :ms, :da, :cc, :cn, :sn, :des, :add, :ru, :telg, :insta, :lat, :lon, :datec, :sw, :stime, :etime, :ei,:urc)";

    $stmt = $conn->prepare($sql);

    // اتصال پارامترها با PDO
    $params = [
        ':pi' => $profilePictureName,
        ':fn' => $input_data['first_name'],
        ':ln' => $input_data['last_name'],
        ':pr' => $input_data['user_province'],
        ':ci' => $input_data['user_city'],
        ':ph' => $input_data['user_phone'],
        ':hp' => $input_data['user_hidePhone'],
        ':em' => $input_data['user_email'],
        ':ge' => $input_data['user_gender'],
        ':ms' => $input_data['user_maritalState'],
        ':da' => $input_data['user_dateOfBirth'],
        ':cc' => $input_data['user_carCategory'],
        ':cn' => $input_data['user_carName'],
        ':sn' => $input_data['user_smartNumber'],
        ':des' => $input_data['user_description'],
        ':add' => $input_data['user_address'],
        ':ru' => $input_data['user_rubika'],
        ':telg' => $input_data['user_telegram'],
        ':insta' => $input_data['user_instagram'],
        ':lat' => $input_data['location_latitude'],
        ':lon' => $input_data['location_longitude'],
        ':datec' => $input_data['date_create'],
        ':sw' => $input_data['user_similarWords'],
        ':stime' => $input_data['user_startTime'],
        ':etime' => $input_data['user_endTime'],
        ':ei' => $input_data['user_eitaa'],
         ':urc' => $input_data['use_referral_code'],
    ];

    foreach ($params as $key => &$val) {
        $stmt->bindParam($key, $val, PDO::PARAM_STR);
    }

    // اجرای دستور SQL داخل ترانزاکشن
    $conn->beginTransaction();
    try {
        $stmt->execute();

        // آماده‌سازی دستور SQL برای جدول users
        $sql_user = "INSERT INTO users (phone, province, city) VALUES (:phone, :province, :city)
                     ON DUPLICATE KEY UPDATE province = :province, city = :city";
        $stmt_user = $conn->prepare($sql_user);
        $params_user = [
            ':phone' => $input_data['user_phone'],
            ':province' => $input_data['user_province'],
            ':city' => $input_data['user_city']
        ];

        foreach ($params_user as $key => &$val) {
            $stmt_user->bindParam($key, $val, PDO::PARAM_STR);
        }

 if (!$resume->phoneExists1($phone, "users")) {
    
        $stmt_user->execute();
}
        $conn->commit();

        // ایجاد توکن جدید پس از موفقیت
        $token = [
            "iss" => ISSUER,
            "aud" => AUDIENCE,
            "iat" => time(),
            "exp" => time() + EXPIRATION_TIME,
            "data" => [
                'user_phone' => $input_data['user_phone'],
                'user_province' => $input_data['user_province'],
                'user_city' => $input_data['user_city'],
                'access_level' => $userRole // حفظ نقش کاربر
            ]
        ];
        $jwt = JWT::encode($token, JWT_KEY);
        http_response_code(200);
        echo json_encode(["message" => "رزومه با موفقیت ایجاد شد.", "jwt" => $jwt], JSON_UNESCAPED_UNICODE);
    } catch (Exception $e) {
        $conn->rollBack();
        $utility->handleError(500, "خطا در ایجاد رزومه و ذخیره کاربر: " . $e->getMessage());
    }
} catch (\Firebase\JWT\ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (\Firebase\JWT\SignatureInvalidException $e) {
    $utility->handleError(401, "توکن نامعتبر است.");
} catch (Exception $e) {
    $utility->handleError(500, "خطایی در سرور رخ داده است: " . $e->getMessage());
}