<?php

header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "امکان اتصال به پایگاه داده وجود ندارد: " . $e->getMessage());
}

$resume = new Resume($conn);
$data = json_decode(file_get_contents("php://input"));

// دریافت و بررسی توکن JWT
$encodedString = $utility->getToken();
$decodedPayload = null;

if ($encodedString) {
    try {
        $decodedToken = JWT::decode($encodedString, JWT_KEY, array('HS256'));
        $decodedPayload = (array) $decodedToken->data;
        if (!isset($decodedPayload['user_phone'])) {
            $utility->handleError(401, "شماره تلفن در توکن یافت نشد.");
        }
        if ($decodedPayload['user_phone'] !== $data->user_phone) {
            $utility->handleError(403, "شماره تلفن در توکن با شماره تلفن ارائه‌شده مطابقت ندارد.");
        }
    } catch (\Firebase\JWT\ExpiredException $e) {
        $utility->handleError(401, "توکن JWT منقضی شده است.");
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $utility->handleError(401, "امضای JWT نامعتبر است.");
    } catch (Exception $e) {
        $utility->handleError(401, "توکن JWT نامعتبر است.");
    }
} else {
    $utility->handleError(400, "توکن JWT در هدر Authorization یافت نشد.");
}

$phone = $utility->validateInput($data->user_phone, 'string');

// بررسی طول شماره تلفن
if (strlen($phone) > 15) {
    $utility->handleError(400, "طول شماره تلفن نمی‌تواند بیشتر از ۱۵ کاراکتر باشد.");
}

// بررسی وجود رزومه
if (!$resume->phoneExists1($phone, "workshop_resume")) {
    $utility->handleError(404, "رزومه‌ای با این شماره تلفن یافت نشد!");
}

// اعتبارسنجی ورودی‌ها
$fields = [
    'user_logoPicture' => 'string',
    'user_samplePhoto1' => 'string',
    'user_samplePhoto2' => 'string',
    'user_samplePhoto3' => 'string',
    'user_name' => 'string',
    'user_workshopManager' => 'string',
    'user_workshopCategory' => 'string',
    'user_similarWords' => 'string',
    'user_province' => 'string',
    'user_city' => 'string',
    'user_address' => 'string',
    'location_latitude' => 'float',
    'location_longitude' => 'float',
    'user_phone' => 'string',
    'user_hidePhone' => 'string',
    'user_telephone' => 'string',
    'user_email' => 'email',
    'user_startTime' => 'string',
    'user_endTime' => 'string',
    'user_licenseNumber' => 'string',
    'user_licensePicture' => 'string',
    'user_educationalCertificatePicture' => 'string',
    'user_website' => 'string',
    'user_instagram' => 'string',
    'user_telegram' => 'string',
    'user_rubika' => 'string',
    'user_eitaa' => 'string',
    'user_description' => 'string',
    'date_create' => 'string',
];

$input_data = [];
foreach ($fields as $key => $type) {
    $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
}

// ذخیره تصاویر
function save_base64_image($base64_image, $path) {
    if ($base64_image) {
        $image_name = uniqid() . '.jpg';
        file_put_contents($path . $image_name, base64_decode($base64_image));
        return $image_name;
    }
    return ""; // اگر تصویری موجود نباشد، مقدار null بازگردانده می‌شود
}




$image_path = "../../../pictuers/";
$logoPicture = $utility->saveBase64Image($input_data['user_logoPicture'] ?? null, $image_path);
$licensePicture = $utility->saveBase64Image($input_data['user_licensePicture'] ?? null, $image_path);
$educationalCertificatePicture = $utility->saveBase64Image($input_data['user_educationalCertificatePicture'] ?? null, $image_path);
$logoPicture = $utility->saveBase64Image($input_data['user_logoPicture'] ?? null, $image_path);
$photo1Name = $utility->saveBase64Image($input_data['user_samplePhoto1'] ?? null, $image_path);
$photo2Name = $utility->saveBase64Image($input_data['user_samplePhoto2'] ?? null, $image_path);
$photo3Name = $utility->saveBase64Image($input_data['user_samplePhoto3'] ?? null, $image_path);



// دستور SQL برای بروزرسانی اطلاعات
$sql = "UPDATE workshop_resume SET
    logo_picture = :logo,
    environment_photo_1 = :ep1,
    environment_photo_2 = :ep2,
    environment_photo_3 = :ep3,
    name = :n,
    workshop_manager = :wm,
    workshop_category = :wc,
    similar_words = :sw,
    province = :pr,
    city = :ci,
    address = :add,
    latitude = :lat,
    longitude = :lon,
    telephone = :tel,
     hide_phone = :hp,
    email = :em,
    start_time = :stime,
    end_time = :etime,
    license_number = :ln,
    license_photo = :lph,
    educational_certificate_photo = :ecph,
    website = :web,
    instagram = :insta,
    telegram = :telg,
    rubika = :ru,
    eitaa = :ei,
    description = :des,
    date_create = :dc
WHERE phone = :ph";

$stmt = $conn->prepare($sql);

// بایند کردن مقادیر
$params = [
    ':logo' => $logoPicture,
    ':ep1' => $photo1Name,
    ':ep2' => $photo2Name,
    ':ep3' => $photo3Name,
    ':n' => $input_data['user_name'],
    ':wm' => $input_data['user_workshopManager'], 
    ':wc' => $input_data['user_workshopCategory'],
    ':sw' => $input_data['user_similarWords'],
    ':pr' => $input_data['user_province'],
    ':ci' => $input_data['user_city'],
    ':add' => $input_data['user_address'],
    ':lat' => $input_data['location_latitude'],
    ':lon' => $input_data['location_longitude'],
    ':ph' => $input_data['user_phone'],// شماره تلفن به عنوان شناسه برای بروزرسانی استفاده می‌شود
    ':hp' => $input_data['user_hidePhone'],
    ':tel' => $input_data['user_telephone'],
    ':em' => $input_data['user_email'],
    ':stime' => $input_data['user_startTime'],
    ':etime' => $input_data['user_endTime'],
    ':ln' => $input_data['user_licenseNumber'],
    ':lph' => $licensePicture,
    ':ecph' => $educationalCertificatePicture,
    ':web' => $input_data['user_website'],
    ':insta' => $input_data['user_instagram'],
    ':telg' => $input_data['user_telegram'],
    ':ru' => $input_data['user_rubika'],
    ':ei' => $input_data['user_eitaa'],
    ':des' => $input_data['user_description'],
    ':dc' => $input_data['date_create'],
];

foreach ($params as $key => &$val) {
    $stmt->bindParam($key, $val, PDO::PARAM_STR);
}

if ($stmt->execute()) {
    // تولید JWT جدید پس از موفقیت‌آمیز بودن بروزرسانی رزومه
    $token_data = [];
    foreach ($fields as $key => $type) {
        $token_data[$key] = $input_data[$key];
    }

 $token = [
        "iss" => ISSUER,
        "aud" => AUDIENCE,
        "iat" => ISSUED_AT,
        "nbf" => NOT_BEFORE,
        "exp" => EXPIRATION_TIME,
        "data" =>  $token_data = [
        'user_phone' => $input_data['user_phone'],
        'user_province' => $input_data['user_province'],
        'user_city' => $input_data['user_city']
    ]
    ];
    try {
         $jwt = JWT::encode($token, JWT_KEY);
        echo json_encode(["message" => "رزومه با موفقیت بروزرسانی شد", "jwt" => $jwt]);
    } catch (Exception $e) {
        $utility->handleError(500, "ایجاد JWT ناموفق بود.");
    }
} else {
    $utility->handleError(503, "بروزرسانی رزومه با شکست مواجه شد.");
}

?>
