<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    http_response_code(503);
    echo json_encode(["message" => "خطا در اتصال به پایگاه داده."]);
    exit();
}

// دریافت داده‌های ورودی
$data = json_decode(file_get_contents("php://input"));

if (!isset($data->user_phone) || empty(trim($data->user_phone))) {
    http_response_code(400);
    echo json_encode(["message" => "شماره تلفن اجباری است."]);
    exit();
}

$phone = htmlspecialchars(strip_tags(trim($data->user_phone)));
$referral_code = isset($data->referral_code) ? htmlspecialchars(strip_tags(trim($data->referral_code))) : null;

try {
    // بررسی وجود کاربر در دیتابیس
    $query_select_user = "SELECT phone, referral_code, user_count, point FROM users WHERE phone = :phone";
    $stmt = $conn->prepare($query_select_user);
    $stmt->bindParam(':phone', $phone);
    $stmt->execute();
    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($user) {
        // اگر کد رفرال قبلاً مقدار نداشته باشد و مقدار جدید ارسال شده باشد، آن را ذخیره کن
        if (empty($user["referral_code"]) && $referral_code) {
            $query_update_referral = "UPDATE users SET referral_code = :referral_code WHERE phone = :phone";
            $stmt = $conn->prepare($query_update_referral);
            $stmt->bindParam(':referral_code', $referral_code);
            $stmt->bindParam(':phone', $phone);
            $stmt->execute();
            $user["referral_code"] = $referral_code;
        }

        // بازگشت اطلاعات کاربر
        echo json_encode([
            "user_phone" => $user["phone"],
            "referral_code" => $user["referral_code"] ?? "",
            "user_count" => $user["user_count"] ?? 0,
            "point" => $user["point"] ?? 0
        ]);
        exit();
    }

    // ثبت اطلاعات کاربر جدید (در صورت ارسال کد رفرال)
    $query_insert = "INSERT INTO users (phone, referral_code, user_count, point) VALUES (:phone, :referral_code, 0, 0)";
    $stmt = $conn->prepare($query_insert);
    $stmt->bindParam(':phone', $phone);
    
    if ($referral_code) {
        $stmt->bindParam(':referral_code', $referral_code);
    } else {
        $stmt->bindValue(':referral_code', null, PDO::PARAM_NULL);
    }

    $stmt->execute();

    echo json_encode([
        "user_phone" => $phone,
        "referral_code" => $referral_code ?? "",
        "user_count" => 0,
        "point" => 0
    ]);

} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(["message" => "خطا در پردازش درخواست."]);
}
?>
