<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "اتصال به پایگاه داده ممکن نیست.");
    die();
}

$resume = new Resume($conn);
$data = json_decode(file_get_contents("php://input"));

if (!isset($data->user_phone) || empty(trim($data->user_phone))) {
    $utility->handleError(400, "شماره تلفن الزامی است.");
    die();
}

$phone = $utility->validateInput($data->user_phone, 'string', 15);

$encodedString = $utility->getToken();
if (!$encodedString) {
    $utility->handleError(401, "توکن احراز هویت یافت نشد.");
    die();
}

try {
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $payload = (array)$decodedToken->data;
    
    $userRole = $payload['access_level'] ?? 'user';
    $isAdmin = in_array($userRole, ['admin', 'manager', 1, 2, 3]);
    
    if (!$isAdmin) {
        if (!isset($payload['user_phone']) || $payload['user_phone'] !== $phone) {
            $utility->handleError(403, "دسترسی غیرمجاز به این شماره تلفن.");
            die();
        }
    }
} catch (Exception $e) {
    $utility->handleError(401, "خطای احراز هویت.");
    die();
}

try {
    $conn->beginTransaction();

    if ($resume->phoneExists1($phone, "school_resume")) {
        $utility->handleError(409, "رزومه قبلاً ثبت شده است.");
        die();
    }

    $fields = [
        'user_logoPicture' => 'string',
        'user_samplePhoto1' => 'string',
        'user_samplePhoto2' => 'string',
        'user_samplePhoto3' => 'string',
        'user_name' => 'string',
        'user_educationalFields' => 'string',
        'user_similarWords' => 'string',
        'user_province' => 'string',
        'user_city' => 'string',
        'user_address' => 'string',
        'location_latitude' => 'float',
        'location_longitude' => 'float',
        'user_phone' => 'string',
        'user_hidePhone' => 'string',
        'user_telephone' => 'string',
        'user_email' => 'email',
        'user_startTime' => 'string',
        'user_endTime' => 'string',
        'user_registrationNumber' => 'string',
        'user_website' => 'string',
        'user_instagram' => 'string',
        'user_telegram' => 'string',
        'user_rubika' => 'string',
        'user_eitaa' => 'string',
        'user_description' => 'string',
        'date_create' => 'string',
        'use_referral_code' => 'string'
    ];

    $input_data = [];
    foreach ($fields as $key => $type) {
        $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
    }

    $image_path = "../../../pictuers/";
    $logoPicture = $utility->saveBase64Image($input_data['user_logoPicture'], $image_path);
    $photo1Name = $utility->saveBase64Image($input_data['user_samplePhoto1'], $image_path);
    $photo2Name = $utility->saveBase64Image($input_data['user_samplePhoto2'], $image_path);
    $photo3Name = $utility->saveBase64Image($input_data['user_samplePhoto3'], $image_path);

    if (!$resume->phoneExists1($phone, "users")) {
        $stmt_user = $conn->prepare("INSERT INTO users (phone, province, city) VALUES (:ph, :pr, :ci)");
        $stmt_user->execute([
            ':ph' => $phone,
            ':pr' => $input_data['user_province'],
            ':ci' => $input_data['user_city']
        ]);
    }

    $sql = "INSERT INTO school_resume (
        logo_picture, environment_photo_1, environment_photo_2, environment_photo_3,
        name, educational_fields, similar_words, province, city, address, latitude, longitude,
        phone, hide_phone, telephone, email, start_time, end_time, registration_number,
        website, instagram, telegram, rubika, eitaa, description, date_create, use_referral_code
    ) VALUES (
        :logo, :ep1, :ep2, :ep3, :n, :ef, :sw, :pr, :ci, :add, :lat, :lon, :ph, :hp, :tel, :em,
        :stime, :etime, :rn, :web, :insta, :telg, :ru, :ei, :des, :dc, :urc
    )";

    $stmt = $conn->prepare($sql);

    $params = [
        ':logo' => $logoPicture,
        ':ep1' => $photo1Name,
        ':ep2' => $photo2Name,
        ':ep3' => $photo3Name,
        ':n' => $input_data['user_name'],
        ':ef' => $input_data['user_educationalFields'],
        ':sw' => $input_data['user_similarWords'],
        ':pr' => $input_data['user_province'],
        ':ci' => $input_data['user_city'],
        ':add' => $input_data['user_address'],
        ':lat' => $input_data['location_latitude'],
        ':lon' => $input_data['location_longitude'],
        ':ph' => $input_data['user_phone'],
        ':hp' => $input_data['user_hidePhone'],
        ':tel' => $input_data['user_telephone'],
        ':em' => $input_data['user_email'],
        ':stime' => $input_data['user_startTime'],
        ':etime' => $input_data['user_endTime'],
        ':rn' => $input_data['user_registrationNumber'],
        ':web' => $input_data['user_website'],
        ':insta' => $input_data['user_instagram'],
        ':telg' => $input_data['user_telegram'],
        ':ru' => $input_data['user_rubika'],
        ':ei' => $input_data['user_eitaa'],
        ':des' => $input_data['user_description'],
        ':dc' => $input_data['date_create'],
        ':urc' => $input_data['use_referral_code'] ?? null
    ];

    $stmt->execute($params);
    $conn->commit();

    $token = [
        "iss" => ISSUER,
        "aud" => AUDIENCE,
        "iat" => time(),
        "exp" => time() + EXPIRATION_TIME,
        "data" => [
            'user_phone' => $phone,
            'user_province' => $input_data['user_province'],
            'user_city' => $input_data['user_city'],
            'access_level' => $userRole
        ]
    ];
    
    $jwt = JWT::encode($token, JWT_KEY);
    echo json_encode([
        "status" => "success",
        "message" => "رزومه با موفقیت ایجاد شد.",
        "jwt" => $jwt
    ], JSON_UNESCAPED_UNICODE);

} catch (PDOException $e) {
    $conn->rollBack();
    $utility->handleError(500, "خطای پایگاه داده.");
} catch (Exception $e) {
    $conn->rollBack();
    $utility->handleError(500, "خطای سیستمی.");
}