<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php'; // بارگذاری تنظیمات JWT
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;

// تابع پاسخ استاندارد ساده‌سازی شده
function respond($status, $data = []) {
    http_response_code($status);
    echo json_encode($data);
    exit();
}

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (PDOException $e) {
    respond(500, ["error" => "خطایی در اتصال به سرور رخ داد"]);
}

// دریافت و اعتبارسنجی داده‌های ورودی
$data = json_decode(file_get_contents("php://input"), true);

if (empty($data['user_phone'])) {
    respond(400, ["error" => "شماره تلفن الزامی است"]);
}

if (empty($data['referral_Code'])) {
    respond(400, ["error" => "کد معرف الزامی است"]);
}

$phone = htmlspecialchars(strip_tags($data['user_phone']));
$referralCode = htmlspecialchars(strip_tags($data['referral_Code']));

// بررسی تکراری نبودن شماره تلفن
try {
    $stmt = $conn->prepare("SELECT phone FROM users WHERE phone = :phone");
    $stmt->bindParam(':phone', $phone);
    $stmt->execute();

    if ($stmt->rowCount() > 0) {
        respond(409, ["error" => "این شماره تلفن قبلا ثبت شده است"]);
    }
} catch (PDOException $e) {
    respond(500, ["error" => "خطایی در پردازش درخواست رخ داد"]);
}

// بررسی تکراری نبودن کد معرف
try {
    $stmt = $conn->prepare("SELECT referral_code FROM users WHERE referral_code = :referral_code");
    $stmt->bindParam(':referral_code', $referralCode);
    $stmt->execute();

    if ($stmt->rowCount() > 0) {
        respond(409, ["error" => "این کد معرف قبلا استفاده شده است"]);
    }
} catch (PDOException $e) {
    respond(500, ["error" => "خطایی در پردازش درخواست رخ داد"]);
}

// درج کاربر جدید در دیتابیس
try {
    $stmt = $conn->prepare("INSERT INTO users (phone, referral_code) VALUES (:phone, :referral_code)");
    $stmt->bindParam(':phone', $phone);
    $stmt->bindParam(':referral_code', $referralCode);

    if ($stmt->execute()) {
        // تولید توکن JWT
        $token = [
             "iss" => ISSUER,
            "aud" => AUDIENCE,
            "iat" => ISSUED_AT,
            "nbf" => NOT_BEFORE,
            "exp" => EXPIRATION_TIME,
            "data" => [
                "phone" => $phone,
                "referral_code" => $referralCode
            ]
        ];

        $jwt = JWT::encode($token, JWT_KEY);
        respond(201, ["jwt" => $jwt]);
    } else {
        respond(500, ["error" => "ثبت نام با خطا مواجه شد"]);
    }
} catch (PDOException $e) {
    respond(500, ["error" => "خطایی در پردازش درخواست رخ داد"]);
}