<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET");

// فایل‌های مورد نیاز
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';

use \Firebase\JWT\JWT;
use \Firebase\JWT\ExpiredException;

$utility = new Utility();

/**
 * تبدیل اعداد انگلیسی به فارسی در یک رشته
 */
function convertToPersianNumbers($number) {
    $persianDigits = ['۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'];
    $englishDigits = range(0, 9);
    return str_replace($englishDigits, $persianDigits, $number);
}

/**
 * تابع بازگشتی برای تبدیل تمامی اعداد (در مقادیر رشته‌ای یا عددی) داخل آرایه به فارسی
 */
function convertAllDigitsInData($data) {
    if (is_array($data)) {
        foreach ($data as $key => $value) {
            $data[$key] = convertAllDigitsInData($value);
        }
        return $data;
    } else {
        // اگر داده رشته‌ای است، به دنبال تمام ارقام ascii بگرد و تبدیل کند
        if (is_string($data)) {
            return preg_replace_callback('/[0-9]/', function($matches) {
                $map = [
                    '0' => '۰',
                    '1' => '۱',
                    '2' => '۲',
                    '3' => '۳',
                    '4' => '۴',
                    '5' => '۵',
                    '6' => '۶',
                    '7' => '۷',
                    '8' => '۸',
                    '9' => '۹'
                ];
                return $map[$matches[0]];
            }, $data);
        } elseif (is_numeric($data)) {
            return convertToPersianNumbers((string)$data);
        }
        return $data;
    }
}

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();
if (!$encodedString) {
    $utility->handleError(401, "توکن ارائه نشده است.");
    exit();
}

try {
    // بررسی اعتبار توکن
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $decodedPayload = (array) $decodedToken->data;
    
    // دریافت شماره موبایل از توکن
    $userPhone = $decodedPayload['phone'] ?? $decodedPayload['user_phone'] ?? null;
    if (!$userPhone) {
        $utility->handleError(400, "شماره موبایل کاربر در توکن وجود ندارد.");
        exit();
    }

    // اتصال به دیتابیس
    $database = new Database();
    $conn = $database->getConnection();

    // استعلام SQL برای دریافت تراکنش‌های کاربر که account_type آنها 'user' است
    $selectQuery = "SELECT 
                        id,
                        point,
                        balance,
                        card_number,
                        card_name,
                        bank_name,
                        date_request,
                        date_payment,
                        time_payment,
                        full_name,
                        phone,
                        referral_code,
                        payment_status,
                        tracking_code,
                        description
                    FROM transaction
                    WHERE phone = :phone AND account_type = 'user'";
    $stmt = $conn->prepare($selectQuery);
    $stmt->bindValue(":phone", $userPhone, PDO::PARAM_STR);
    $stmt->execute();

    // دریافت نتایج
    $transactions = $stmt->fetchAll(PDO::FETCH_ASSOC);
    if (!$transactions) {
        http_response_code(200);
        echo json_encode(["message" => "شما هیچ تراکنشی ندارید."], JSON_UNESCAPED_UNICODE);
        exit();
    }

    // تبدیل مقادیر خاص مانند balance به فارسی با فرمت مناسب
    foreach ($transactions as &$transaction) {
        if (isset($transaction['balance'])) {
            $formattedBalance = number_format($transaction['balance'], 0, '', ',');
            $transaction['formatted_balance'] = convertToPersianNumbers($formattedBalance) . ' ریال';
        }
    }
    
    // تبدیل تمامی اعداد موجود در تمامی فیلدها به صورت بازگشتی به فارسی
    $transactions = convertAllDigitsInData($transactions);

    // ارسال پاسخ به کاربر
    http_response_code(200);
    echo json_encode(["transactions" => $transactions], JSON_UNESCAPED_UNICODE);

} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (\Firebase\JWT\SignatureInvalidException $e) {
    $utility->handleError(401, "توکن نامعتبر است.");
} catch (Exception $e) {
    $utility->handleError(500, "خطایی در سرور رخ داده است.");
}
?>
