<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");

// فایل‌های مورد نیاز
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/JWT.php';
require_once $_SERVER['DOCUMENT_ROOT'] . '/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';

use \Firebase\JWT\JWT;
use \Firebase\JWT\ExpiredException;

$utility = new Utility();

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();
if (!$encodedString) {
    $utility->handleError(401, "توکن ارائه نشده است.");
    echo json_encode(["error" => "توکن در هدر ارسال نشده است."]);
    exit();
}

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));
if (json_last_error() !== JSON_ERROR_NONE) {
    $utility->handleError(400, "فرمت داده‌های ورودی نادرست است.");
    echo json_encode(["error" => "فرمت داده‌های ورودی نادرست است: " . json_last_error_msg()]);
    exit();
}

// اعتبارسنجی داده‌های ورودی
if (empty($data->referral_code)) {
    $utility->handleError(400, "لطفاً کد معرف را وارد کنید.");
    echo json_encode(["error" => "کد معرف ارسال نشده است."]);
    exit();
}

try {
    // بررسی اعتبار توکن
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $decodedPayload = (array) $decodedToken->data;
} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
    echo json_encode(["error" => "توکن منقضی شده است: " . $e->getMessage()]);
    exit();
} catch (\Firebase\JWT\SignatureInvalidException $e) {
    $utility->handleError(401, "توکن نامعتبر است.");
    echo json_encode(["error" => "توکن نامعتبر است: " . $e->getMessage()]);
    exit();
} catch (Exception $e) {
    $utility->handleError(500, "خطای عمومی در سرور.");
    echo json_encode(["error" => "خطای عمومی در سرور: " . $e->getMessage()]);
    exit();
}

// اتصال به دیتابیس
$database = new Database();
$conn = $database->getConnection();
if (!$conn) {
    $utility->handleError(500, "اتصال به پایگاه داده ناموفق بود.");
    echo json_encode(["error" => "اتصال به پایگاه داده ناموفق بود."]);
    exit();
}

try {
    // شروع تراکنش
    $conn->beginTransaction();

    // بررسی وجود referral_code در دیتابیس
    $checkQuery = "SELECT referral_code FROM users WHERE referral_code = :referral_code";
    $checkStmt = $conn->prepare($checkQuery);
    $checkStmt->bindValue(":referral_code", $data->referral_code, PDO::PARAM_STR);
    $checkStmt->execute();

    $foundRows = $checkStmt->rowCount();
    if ($foundRows === 0) {
        $conn->rollBack();
        $utility->handleError(404, "کاربری با کد معرف داده شده یافت نشد.");
        echo json_encode(["error" => "کد معرف در پایگاه داده یافت نشد."]);
        exit();
    }

    // اجرای به‌روزرسانی
    $updateQuery = "UPDATE users 
                    SET user_count = user_count + 1, 
                        point = point + 10
                    WHERE referral_code = :referral_code";
    $updateStmt = $conn->prepare($updateQuery);
    $updateStmt->bindValue(":referral_code", $data->referral_code, PDO::PARAM_STR);

    if ($updateStmt->execute()) {
        $affectedRows = $updateStmt->rowCount();
        if ($affectedRows > 0) {
            $conn->commit();
            echo json_encode(["message" => "۱۰ امتیاز دریافت کردید."]);
        } else {
            $conn->rollBack();
            $utility->handleError(500, "خطا در به‌روزرسانی اطلاعات کاربر.");
            echo json_encode(["error" => "هیچ ردیفی در جدول به‌روزرسانی نشد."]);
        }
    } else {
        $conn->rollBack();
        $utility->handleError(500, "به‌روزرسانی انجام نشد. لطفاً دوباره تلاش کنید.");
        echo json_encode(["error" => "خطا در اجرای دستور UPDATE."]);
    }
} catch (Exception $e) {
    $conn->rollBack();
    $utility->handleError(500, "خطای غیرمنتظره در اجرای درخواست.");
    echo json_encode(["error" => "خطای غیرمنتظره در اجرای درخواست: " . $e->getMessage()]);
}
?>
