<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");

// شامل کردن فایل‌های مورد نیاز
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

use \Firebase\JWT\JWT;
$utility = new Utility();

// دریافت توکن از هدر Authorization
$encodedString = $utility->getToken();
if (!$encodedString) {
    $utility->handleError(400, "توکن JWT در هدر Authorization یافت نشد.");
    exit();
}

// دریافت داده‌های ورودی از بدنه درخواست
$data = json_decode(file_get_contents("php://input"));
if (empty($data->user_phone)) {
    $utility->handleError(400, "شماره تلفن کاربر الزامی است.");
    exit();
}
$phone = $utility->validateInput($data->user_phone, 'string');
if (strlen($phone) > 15) {
    $utility->handleError(400, "شماره تلفن نمی‌تواند بیشتر از 15 کاراکتر باشد.");
    exit();
}

try {
    // بررسی اعتبار توکن
    $decodedToken = JWT::decode($encodedString, JWT_KEY, ['HS256']);
    $decodedPayload = (array) $decodedToken->data;
    // بررسی نقش کاربر (user یا admin/manager)
    $userRole = $decodedPayload['access_level'] ?? 'user';
    $isAdminOrManager = in_array($userRole, ['manager', '1','2','3']);
    // اگر کاربر admin/manager نباشد، بررسی می‌کنیم که شماره تلفن در توکن با شماره تلفن ارائه شده مطابقت دارد
    if (!$isAdminOrManager) {
        if (!isset($decodedPayload['user_phone'])) {
            $utility->handleError(401, "شماره تلفن در توکن یافت نشد.");
            exit();
        }
        if ($decodedPayload['user_phone'] !== $data->user_phone) {
            $utility->handleError(403, "شماره تلفن در توکن با شماره تلفن ارائه شده مطابقت ندارد.");
            exit();
        }
    }

    // اتصال به دیتابیس
    $database = new Database();
    $conn = $database->getConnection();

    // بررسی وجود شماره تلفن در جدول users
    $user = new User($conn);
    $resume = new Resume($conn);

   

    if ($resume->phoneExists1($phone, "workshop_resume")) {
        $utility->handleError(409, "این معرفی نامه از قبل ثبت شده است.");
        die();
    }

    // اعتبارسنجی و پاک‌سازی ورودی‌ها
    $fields = [
        'user_logoPicture' => 'string',
        'user_samplePhoto1' => 'string',
        'user_samplePhoto2' => 'string',
        'user_samplePhoto3' => 'string',
        'user_name' => 'string',
        'user_workshopManager' => 'string',
        'user_workshopCategory' => 'string',
        'user_similarWords' => 'string',
        'user_province' => 'string',
        'user_city' => 'string',
        'user_address' => 'string',
        'location_latitude' => 'float',
        'location_longitude' => 'float',
        'user_phone' => 'string',
        'user_hidePhone' => 'string',
        'user_telephone' => 'string',
        'user_email' => 'email',
        'user_startTime' => 'string',
        'user_endTime' => 'string',
        'user_licenseNumber' => 'string',
        'user_licensePicture' => 'string',
        'user_educationalCertificatePicture' => 'string',
        'user_website' => 'string',
        'user_instagram' => 'string',
        'user_telegram' => 'string',
        'user_rubika' => 'string',
        'user_eitaa' => 'string',
        'user_description' => 'string',
        'date_create' => 'string',
        'use_referral_code' => 'string', // اضافه کردن فیلد رفرال کد
    ];

    $input_data = [];
    foreach ($fields as $key => $type) {
        $input_data[$key] = $utility->validateInput($data->$key ?? null, $type);
    }

    // ذخیره تصاویر
    $image_path = "../../../pictuers/";
    $logoPicture = $utility->saveBase64Image($input_data['user_logoPicture'] ?? null, $image_path);
    $licensePicture = $utility->saveBase64Image($input_data['user_licensePicture'] ?? null, $image_path);
    $educationalCertificatePicture = $utility->saveBase64Image($input_data['user_educationalCertificatePicture'] ?? null, $image_path);
    $photo1Name = $utility->saveBase64Image($input_data['user_samplePhoto1'] ?? null, $image_path);
    $photo2Name = $utility->saveBase64Image($input_data['user_samplePhoto2'] ?? null, $image_path);
    $photo3Name = $utility->saveBase64Image($input_data['user_samplePhoto3'] ?? null, $image_path);

    // آماده‌سازی دستور SQL برای جدول workshop_resume
    $sql_resume = "INSERT INTO workshop_resume
            (logo_picture, environment_photo_1, environment_photo_2, environment_photo_3,
            name, workshop_manager, workshop_category, similar_words,
            province, city, address, latitude, longitude,
            phone, hide_phone, telephone, email, 
            start_time, end_time,
            license_number, license_photo, educational_certificate_photo,
            website, instagram, telegram, rubika, eitaa,
            description, date_create, use_referral_code) -- اضافه کردن فیلد use_referral_code
            VALUES
            (:logo, :ep1, :ep2, :ep3, :n, :wm, :wc, :sw,
            :pr, :ci, :add, :lat, :lon, :ph, :hp, :tel, :em,
            :stime, :etime, :ln, :lph, :ecph, 
            :web, :insta, :telg, :ru, :ei, :des, :dc, :urc)";
    
    $stmt_resume = $conn->prepare($sql_resume);
    $params_resume = [
        ':logo' => $logoPicture,
        ':ep1' => $photo1Name,
        ':ep2' => $photo2Name,
        ':ep3' => $photo3Name,
        ':n' => $input_data['user_name'],
        ':wm' => $input_data['user_workshopManager'],
        ':wc' => $input_data['user_workshopCategory'],
        ':sw' => $input_data['user_similarWords'],
        ':pr' => $input_data['user_province'],
        ':ci' => $input_data['user_city'],
        ':add' => $input_data['user_address'],
        ':lat' => $input_data['location_latitude'],
        ':lon' => $input_data['location_longitude'],
        ':ph' => $input_data['user_phone'],
        ':hp' => $input_data['user_hidePhone'],
        ':tel' => $input_data['user_telephone'],
        ':em' => $input_data['user_email'],
        ':stime' => $input_data['user_startTime'],
        ':etime' => $input_data['user_endTime'],
        ':ln' => $input_data['user_licenseNumber'],
        ':lph' => $licensePicture,
        ':ecph' => $educationalCertificatePicture,
        ':web' => $input_data['user_website'],
        ':insta' => $input_data['user_instagram'],
        ':telg' => $input_data['user_telegram'],
        ':ru' => $input_data['user_rubika'],
        ':ei' => $input_data['user_eitaa'],
        ':des' => $input_data['user_description'],
        ':dc' => $input_data['date_create'],
        ':urc' => $input_data['use_referral_code'], // اضافه کردن پارامتر use_referral_code
    ];
    
    foreach ($params_resume as $key => &$val) {
        $stmt_resume->bindParam($key, $val, PDO::PARAM_STR);
    }


     if (!$user->phoneExists($phone)) {
    // آماده‌سازی دستور SQL برای جدول users
    $sql_user = "INSERT INTO users (phone,province, city) VALUES (:phone,  :province, :city)
                 ON DUPLICATE KEY UPDATE  province = :province, city = :city";
    $stmt_user = $conn->prepare($sql_user);
    $params_user = [
        ':phone' => $input_data['user_phone'],
        ':province' => $input_data['user_province'],
        ':city' => $input_data['user_city']
    ];
}
    foreach ($params_user as $key => &$val) {
        $stmt_user->bindParam($key, $val, PDO::PARAM_STR);
    }

    // اجرای دو دستور SQL داخل ترانزاکشن
    $conn->beginTransaction();
    try {
        $stmt_resume->execute();
        if ($stmt_user  !=null){
             $stmt_user->execute();
        }
       
        $conn->commit();
        
        // ایجاد توکن جدید پس از موفقیت
        $token = [
            "iss" => ISSUER,
            "aud" => AUDIENCE,
            "iat" => time(),
            "exp" => time() + EXPIRATION_TIME,
            "data" => [
                'user_phone' => $input_data['user_phone'],
                'user_province' => $input_data['user_province'],
                'user_city' => $input_data['user_city'],
                'access_level' => $userRole // حفظ نقش کاربر
            ]
        ];
        $jwt = JWT::encode($token, JWT_KEY);
        http_response_code(200);
        echo json_encode(["message" => "رزومه با موفقیت ایجاد شد.", "jwt" => $jwt], JSON_UNESCAPED_UNICODE);
    } catch (Exception $e) {
        $conn->rollBack();
        $utility->handleError(500, "خطا در ایجاد رزومه و ذخیره کاربر: " . $e->getMessage());
    }
} catch (ExpiredException $e) {
    $utility->handleError(401, "توکن منقضی شده است.");
} catch (SignatureInvalidException $e) {
    $utility->handleError(401, "توکن نامعتبر است.");
} catch (Exception $e) {
    $utility->handleError(500, "خطایی در سرور رخ داده است: " . $e->getMessage());
}