<?php
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");

require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/Database.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/Resume.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/data/User.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/validate.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/auth/class.Utility.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/config/core.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/BeforeValidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/ExpiredException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/SignatureInvalidException.php';
require_once $_SERVER['DOCUMENT_ROOT'].'/jobfinder/src/libs/php-jwt-master/src/JWT.php';

$utility = new Utility();

try {
    $database = new Database();
    $conn = $database->getConnection();
} catch (Exception $e) {
    $utility->handleError(503, "عدم توانایی در اتصال به پایگاه داده: " . $e->getMessage());
    die();
}

$resume = new Resume($conn);
$user = new User($conn);

$data = json_decode(file_get_contents("php://input"));

if (!isset($data->user_phone) || empty($data->user_phone)) {
    $utility->handleError(400, "شماره تلفن کاربر الزامی است.");
    die();
}

$phone = htmlspecialchars(strip_tags($data->user_phone));

// بررسی وجود رزومه
if (!$resume->phoneExists1($phone, "workshop_resume")) {
    $utility->handleError(404, "رزومه یافت نشد!");
    die();
}

// اجرای دستور SQL برای خواندن رزومه
$sql = "SELECT * FROM workshop_resume WHERE phone = :phone";
$stmt = $conn->prepare($sql);
$stmt->bindParam(':phone', $phone, PDO::PARAM_STR);

if ($stmt->execute()) {
    $data = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($data) {
        $arrUser = [];
        foreach ($data as $key => $value) {
            $arrUser["user_" . $key] = $value;
        }

        http_response_code(200);
        echo json_encode($arrUser, JSON_UNESCAPED_UNICODE);
    } else {
        $utility->handleError(404, "رزومه یافت نشد!");
    }
} else {
    $utility->handleError(500, "امکان خواندن رزومه وجود ندارد.");
}
?>