<?php
class Utility {
    // این متد توکن JWT را از هدر Authorization استخراج می‌کند
    public function getToken() {
        $headers = null;
        if (isset($_SERVER['Authorization'])) {
            $headers = trim($_SERVER["Authorization"]);
        } elseif (isset($_SERVER['HTTP_AUTHORIZATION'])) {
            $headers = trim($_SERVER["HTTP_AUTHORIZATION"]);
        } elseif (function_exists('apache_request_headers')) {
            $requestHeaders = apache_request_headers();
            $requestHeaders = array_combine(array_map('ucwords', array_keys($requestHeaders)), array_values($requestHeaders));
            if (isset($requestHeaders['Authorization'])) {
                $headers = trim($requestHeaders['Authorization']);
            }
        }

        if (!empty($headers) && preg_match('/Bearer\s(\S+)/', $headers, $matches)) {
            return $matches[1];
        }

        return null;
    }


public function validateJWT($phone)
{
    try {
        $encodedString = $this->getToken();

        if ($encodedString) {
            $decodedToken = \Firebase\JWT\JWT::decode($encodedString, JWT_KEY, ['HS256']);
            $decodedPayload = (array) $decodedToken->data;

            if (!isset($decodedPayload['user_phone'])) {
                $this->handleError(401, "شماره تلفن در توکن یافت نشد.");
                return false;
            }

            if ($decodedPayload['user_phone'] !== $phone) {
                $this->handleError(403, "شماره تلفن در توکن با شماره تلفن ارائه شده مطابقت ندارد.");
                return false;
            }

        } else {
            $this->handleError(400, "هیچ توکن JWT در هدر Authorization یافت نشد.");
            return false;
        }
    } catch (\Firebase\JWT\ExpiredException $e) {
        $this->handleError(401, "توکن JWT منقضی شده است.");
        return false;
    } catch (\Firebase\JWT\SignatureInvalidException $e) {
        $this->handleError(401, "امضای JWT نامعتبر است.");
        return false;
    } catch (Exception $e) {
        $this->handleError(401, "توکن JWT نامعتبر است.");
        return false;
    }

    return true;
}


    // تابع برای دیکود کردن Base64Url
    public  function base64UrlDecode($input) {
        $remainder = strlen($input) % 4;
        if ($remainder) {
            $padlen = 4 - $remainder;
            $input .= str_repeat('=', $padlen);
        }
        return base64_decode(strtr($input, '-_', '+/'));
    }

    // Helper function to validate and sanitize input data
    public function validateInput($data, $type) {
        switch ($type) {
            case 'email':
                return filter_var($data, FILTER_VALIDATE_EMAIL);
            case 'double':
                return filter_var($data, FILTER_VALIDATE_FLOAT);
            case 'int':
                return filter_var($data, FILTER_VALIDATE_INT);
            case 'string':
            default:
                return filter_var($data, FILTER_SANITIZE_STRING);
        }
    }

    // Function to handle file uploads
    public function saveBase64Image($base64Image, $path) {
        if ($base64Image) {
            $imageName = uniqid() . '.jpg';
            if (file_put_contents($path . $imageName, base64_decode($base64Image)) === false) {
                return null;
            }
            return $imageName;
        }
        return "";
    }
    
     public function saveBase64Image1($base64Image, $path) {
        if ($base64Image) {
            $imageName = uniqid() . '.jpg';
            if (!file_exists($path)) {
                if (!mkdir($path, 0755, true)) {
                    error_log("Failed to create directory: " . $path);
                    return null;
                }
            }
            if (file_put_contents($path . $imageName, base64_decode($base64Image)) === false) {
                error_log("Failed to save the image to " . $path . $imageName);
                return null;
            }
            return $imageName;
        }
        return "";
    }

   // تابع برای ارسال خطا
public function handleError($code, $message) {
    http_response_code($code);
    echo json_encode(array("message" => $message), JSON_UNESCAPED_UNICODE);
    die();
}

}
